#[repr(C, packed(1))]pub struct Waet {
pub header: Sdt,
pub emulated_device_flags: u32,
}Expand description
The Windows ACPI Emulated devices Table (WAET) allows virtualized OSes to avoid workarounds for errata on physical devices.
Fields
header: Sdtemulated_device_flags: u32Implementations
Sourceimpl Waet
impl Waet
Sourcepub fn get() -> Option<&'static Waet>
pub fn get() -> Option<&'static Waet>
Finds the WAET in the given AcpiTables and returns a reference to it.
Sourcepub fn rtc_good(&self) -> bool
pub fn rtc_good(&self) -> bool
Returns whether the RTC has been enhanced not to require acknowledgment after it asserts an interrupt.
Sourcepub fn acpi_pm_timer_good(&self) -> bool
pub fn acpi_pm_timer_good(&self) -> bool
Returns whether the ACPI PM timer has been enhanced not to require multiple reads.