fn dump_memory_bytes(vaddr: u64, cr3_phys: u64, count: usize, prefix: &str)
Hex + ASCII dump of count bytes at virtual address vaddr. Each page boundary is translated through the raw page tables.
count
vaddr