resched_ipi_handler

Function resched_ipi_handler 

extern "x86-interrupt" fn resched_ipi_handler(
    stack_frame: InterruptStackFrame,
)
Cross-CPU reschedule IPI handler (vector 0xF0).

Sent by another CPU (via apic::send_resched_ipi) to request that this CPU preempts its current task immediately rather than waiting for the next timer tick. This is used when a task running on this CPU is killed or suspended by a different CPU.

EOI is sent before maybe_preempt() so the APIC can accept further IPIs before the potentially long context-switch path runs.