enable_msi

Function enable_msi 

fn enable_msi(pci_dev: &PciDevice, vector: u8) -> bool
Try to enable MSI on pci_dev with vector.

Returns true on success, false if MSI is not supported or programming failed. On success the device will deliver interrupts via MSI instead of legacy INTx.

Note

This does not clear the INTx_DISABLE bit in the PCI command register. The caller should set COMMAND.INTx_DISABLE after enabling MSI to prevent the device from also asserting its legacy interrupt pin.