read_gdt_raw

Function read_gdt_raw 

unsafe fn read_gdt_raw(gdt_base: *const u64, index: usize) -> u64
Reads an 8-byte GDT descriptor at the given index (base 0).

Safety

gdt_base must be the address returned by sgdt and index must remain within the limit of the GDTR.