pub fn broadcast_panic_halt()Expand description
Broadcast a halt command to all other CPUs.
Used during panic to stop the system and prevent log corruption.
pub fn broadcast_panic_halt()Broadcast a halt command to all other CPUs.
Used during panic to stop the system and prevent log corruption.