set_kernel_rsp

Function set_kernel_rsp 

pub fn set_kernel_rsp(rsp: u64)
Update the kernel RSP used by the SYSCALL entry point.

Called by the scheduler on every context switch to point to the top of the new task’s kernel stack.