pub fn vgabuf_flush_to_framebuffer()Expand description
Render a bounded batch. Retrying pending presents also displays the last keyboard echo/log fragment when no subsequent message arrives.
pub fn vgabuf_flush_to_framebuffer()Render a bounded batch. Retrying pending presents also displays the last keyboard echo/log fragment when no subsequent message arrives.