#[repr(C)]pub struct AsyncCqe {
pub user_data: u64,
pub res: i32,
pub flags: u32,
}Expand description
A single I/O completion, written by the kernel into the CQ ring.
Fields
user_data: u64Opaque correlation token from the originating SQE.
res: i32Result: bytes transferred on success, or a negative errno on failure.
flags: u32Flags: CQE_F_BUFFER, CQE_F_MORE.