pub unsafe fn init_block_device_from_dtb(
dtb_ptr: u64,
) -> Option<&'static mut dyn BlockDevice>Expand description
Initialize a block device from the Device Tree.
Safety
dtb_ptr must point to a valid flattened device tree.
pub unsafe fn init_block_device_from_dtb(
dtb_ptr: u64,
) -> Option<&'static mut dyn BlockDevice>Initialize a block device from the Device Tree.
dtb_ptr must point to a valid flattened device tree.