build_kernel_args_from_dtb

Function build_kernel_args_from_dtb 

pub unsafe fn build_kernel_args_from_dtb(dtb_ptr: u64) -> KernelArgs
Parse the Flattened Device Tree and build a KernelArgs structure.

Safety

dtb_ptr must point to a valid flattened device tree in memory.