VirtioBlkDevice

Struct VirtioBlkDevice 

pub struct VirtioBlkDevice {
    base_addr: u64,
    block_size: u64,
    features: u32,
    queue: Option<BootVirtqueue>,
}
VirtIO block device (boot-time MMIO transport)

Fields

base_addr: u64

Base address of the device registers (MMIO BAR)

block_size: u64

Block size in bytes

features: u32

Device features

queue: Option<BootVirtqueue>

Boot-time virtqueue

Implementations

Source

impl VirtioBlkDevice

pub unsafe fn new(base_addr: u64) -> Self

Create a new VirtIO block device from MMIO base address.

Safety

base_addr must point to valid VirtIO device registers.

pub unsafe fn init(&mut self) -> Result<(), &'static str>

Initialize the VirtIO block device.

Safety

Must only be called once with a valid device address.

unsafe fn read_status(&self) -> u32

unsafe fn write_status(&self, val: u32)

unsafe fn add_status(&self, bit: u32)

unsafe fn read_device_features(&self) -> u32

unsafe fn write_driver_features(&self, features: u32)

pub unsafe fn from_dtb(dtb_ptr: u64) -> Option<Self>

Create a VirtIO block device from a Device Tree node.

Safety

dtb_ptr must point to a valid flattened device tree.