pub struct CapabilityTable { /* private fields */ }Expand description
Table of capabilities for a process
Implementations
Sourceimpl CapabilityTable
impl CapabilityTable
Sourcepub fn insert(&mut self, cap: Capability) -> CapId
pub fn insert(&mut self, cap: Capability) -> CapId
Insert a capability into the table
Sourcepub fn remove(&mut self, id: CapId) -> Option<Capability>
pub fn remove(&mut self, id: CapId) -> Option<Capability>
Remove a capability from the table
Sourcepub fn get(&self, id: CapId) -> Option<&Capability>
pub fn get(&self, id: CapId) -> Option<&Capability>
Get a reference to a capability (no permission check).
Sourcepub fn revoke_all(&mut self)
pub fn revoke_all(&mut self)
Revoke all capabilities in this table and clear it. Does not allocate memory.
Sourcepub fn has_resource_type_with_permissions(
&self,
resource_type: ResourceType,
required: CapPermissions,
) -> bool
pub fn has_resource_type_with_permissions( &self, resource_type: ResourceType, required: CapPermissions, ) -> bool
Check whether any capability of the given resource type has required permissions.
Sourcepub fn has_resource_with_permissions(
&self,
resource_type: ResourceType,
resource: usize,
required: CapPermissions,
) -> bool
pub fn has_resource_with_permissions( &self, resource_type: ResourceType, resource: usize, required: CapPermissions, ) -> bool
Check whether a specific resource has required permissions.
Sourcepub fn get_with_permissions(
&self,
id: CapId,
required: CapPermissions,
) -> Option<&Capability>
pub fn get_with_permissions( &self, id: CapId, required: CapPermissions, ) -> Option<&Capability>
Get a reference to a capability if it exists and has the required permissions
Sourcepub fn get_mut_with_permissions(
&mut self,
id: CapId,
required: CapPermissions,
) -> Option<&mut Capability>
pub fn get_mut_with_permissions( &mut self, id: CapId, required: CapPermissions, ) -> Option<&mut Capability>
Get a mutable reference to a capability if it exists and has the required permissions
Sourcepub fn duplicate(&mut self, id: CapId) -> Option<Capability>
pub fn duplicate(&mut self, id: CapId) -> Option<Capability>
Duplicate a capability (grant permission required)