pub(crate) fn register_boot_modules(modules: &[ModuleEntry])Expand description
Register modules from the validated bootloader module table.
Each module has a name, physical base address, and size.
The kernel maps them into the VFS at /initfs/
pub(crate) fn register_boot_modules(modules: &[ModuleEntry])Register modules from the validated bootloader module table.
Each module has a name, physical base address, and size.
The kernel maps them into the VFS at /initfs/