fn init_data_plane()Expand description
Initialise the N2 data plane with one ring pair per registered device. Each device gets a single RX/TX pair (RSS queues extend this).
fn init_data_plane()Initialise the N2 data plane with one ring pair per registered device. Each device gets a single RX/TX pair (RSS queues extend this).