pub fn init()Expand description
Initialize VirtIO block device
Scans PCI bus for VirtIO block devices and initializes the first one found.
pub fn init()Initialize VirtIO block device
Scans PCI bus for VirtIO block devices and initializes the first one found.