fn alloc_frame_slot() -> Option<(usize, *mut MigrationFrame)>Expand description
Allocate a MigrationFrame from the static pool.
Returns a pointer to the frame and its pool index.
fn alloc_frame_slot() -> Option<(usize, *mut MigrationFrame)>Allocate a MigrationFrame from the static pool.
Returns a pointer to the frame and its pool index.