fn safe_kernel_rflags() -> u64Expand description
Return safe kernel-mode rflags for N3 context switching.
Bit 1 (reserved) must always be 1. Bit 9 (IF) is set to keep interrupts enabled in the kernel handler. All other bits are cleared to avoid restoring user-modified flags (TF, AC, etc.) into kernel context.