struct MsgBuffer(*mut u8);Expand description
Wrapper for a raw pointer to the shared message buffer.
Safety
The pointer is valid for the lifetime of the N3Transport and is mapped in both sender and receiver address spaces. All access is serialized by the MigrationFrame state machine.
Tuple Fields
0: *mut u8Implementations