cancel_replies_waiting_on

Function cancel_replies_waiting_on 

pub fn cancel_replies_waiting_on(dead_task: TaskId)
Cancel all pending reply slots and wake blocked callers with EPIPE.

Called during task cleanup to unblock any tasks waiting for a reply that this dying task should have delivered.