wait_for_reply

Function wait_for_reply 

pub fn wait_for_reply(task_id: TaskId, waiting_on: TaskId) -> IpcMessage
Block the current task waiting for a reply message (synchronous call path).

The caller (via SYS_IPC_CALL) blocks on a WaitQueue until the server calls deliver_reply. Returns the reply message; returns an EPIPE error if the slot was removed while waiting (server died).