macro_rules! boot_milestone {
($($arg:tt)*) => { ... };
}Expand description
Log a boot milestone with elapsed time since kernel entry.
Output format: [boot + 12ms] Paging initialized
macro_rules! boot_milestone {
($($arg:tt)*) => { ... };
}Log a boot milestone with elapsed time since kernel entry.
Output format: [boot + 12ms] Paging initialized