macro_rules! e9_mark {
($byte:expr) => { ... };
}Expand description
Raw e9 debugcon marker: writes a single byte to port 0xe9 using inline asm. This works even when the Port type from x86_64 crate doesn’t.
macro_rules! e9_mark {
($byte:expr) => { ... };
}Raw e9 debugcon marker: writes a single byte to port 0xe9 using inline asm. This works even when the Port type from x86_64 crate doesn’t.