macro_rules! serial_force_println {
() => { ... };
($($arg:tt)*) => { ... };
}Expand description
Print to serial port with newline, bypassing the shared mutex.
macro_rules! serial_force_println {
() => { ... };
($($arg:tt)*) => { ... };
}Print to serial port with newline, bypassing the shared mutex.