resolve_handle

Function resolve_handle 

pub fn resolve_handle(phys: PhysAddr) -> BlockHandle
Resolves a physical address to the current block handle. If the address is not currently owned, a new handle is reconstructed from the metadata.