pub struct BootAllocator {
regions: [BootRegion; 512],
len: usize,
accessible_limit: u64,
}Fields
regions: [BootRegion; 512]len: usizeaccessible_limit: u64Implementations
Sourceimpl BootAllocator
impl BootAllocator
pub const fn new() -> Self
pub fn init(&mut self, regions: &[MemoryRegion])
pub fn alloc(&mut self, size: usize, align: usize) -> PhysAddr
pub fn try_alloc(&mut self, size: usize, align: usize) -> Option<PhysAddr>
pub fn try_alloc_accessible( &mut self, size: usize, align: usize, ) -> Option<PhysAddr>
pub fn snapshot_free_regions(&self, out: &mut [MemoryRegion]) -> usize
fn reset(&mut self)
fn push_region(&mut self, region: BootRegion)
fn exclude_range(&mut self, exclude_start: u64, exclude_end: u64)
fn consume_region(&mut self, idx: usize, alloc_start: u64, alloc_end: u64)
fn insert_region(&mut self, idx: usize, region: BootRegion)
fn remove_region(&mut self, idx: usize)
fn normalize_regions(&mut self)
Sourcefn rebuild_accessible_limit(&mut self)
fn rebuild_accessible_limit(&mut self)
Recompute the highest currently reachable physical byte for HHDM-backed boot allocations.
Sourcefn accessible_prefix_end(&self, region: BootRegion) -> u64
fn accessible_prefix_end(&self, region: BootRegion) -> u64
Return the end of the longest mapped prefix of region visible through the current HHDM.
pub fn stats(&self) -> BootAllocStats