pub fn free(_token: &IrqDisabledToken, frame: PhysFrame, order: u8)Expand description
Free frames with per-CPU caching on order-0 requests.
_token is a compile-time proof that interrupts are disabled on the calling CPU.
pub fn free(_token: &IrqDisabledToken, frame: PhysFrame, order: u8)Free frames with per-CPU caching on order-0 requests.
_token is a compile-time proof that interrupts are disabled on the calling CPU.