pub fn handle_get_refcount(handle: BlockHandle) -> u32Expand description
Returns the current shared reference count of a physical block.
pub fn handle_get_refcount(handle: BlockHandle) -> u32Returns the current shared reference count of a physical block.