pub fn mapping_index() -> &'static MappingIndexExpand description
Returns the global reverse mapping index used by the memory runtime.
pub fn mapping_index() -> &'static MappingIndexReturns the global reverse mapping index used by the memory runtime.