pub fn init_metadata_array(total_ram: u64, boot_alloc: &mut BootAllocator)Expand description
Initialize the global metadata array for all physical frames.
pub fn init_metadata_array(total_ram: u64, boot_alloc: &mut BootAllocator)Initialize the global metadata array for all physical frames.