FrameMeta

Struct FrameMeta 

pub struct FrameMeta { /* private fields */ }
Intriside metadata for a physical frame.

  • 64 bytes (one cache line) for efficient atomic access and to avoid false sharing.

Implementations

Source

impl FrameMeta

pub const fn new() -> Self

Create emplty metadata ready to be initialized by the boot allocator.

pub fn next(&self) -> u64

pub fn set_next(&self, next: u64)

pub fn prev(&self) -> u64

pub fn set_prev(&self, prev: u64)

pub fn inc_ref(&self)

pub fn dec_ref(&self) -> u32

pub fn get_refcount(&self) -> u32

pub fn set_flags(&self, flags: u32)

pub fn get_flags(&self) -> u32

pub fn get_order(&self) -> u8

pub fn set_order(&self, order: u8)

pub fn reset_refcount(&self)

pub fn is_cow(&self) -> bool

pub fn is_dll(&self) -> bool