RemoveRefResult

Enum RemoveRefResult 

pub enum RemoveRefResult {
    Freed(PhysBlock<Released>),
    NowExclusive {
        remaining_cap: CapId,
    },
    StillPinned {
        transient_refs: u32,
    },
    StillShared {
        refcount: u32,
    },
}
Result of removing one capability reference from a block.

Variants



Freed(PhysBlock<Released>)

The block has no remaining owners and can return to the buddy.



NowExclusive

Exactly one owner remains.

Fields

remaining_cap: CapId

The last remaining capability.



StillPinned

No capability remains, but transient pins still keep the block alive.

Fields

transient_refs: u32

Current transient reference count.



StillShared

Multiple owners still reference the block.

Fields

refcount: u32

Current shared reference count.