map_page

Function map_page 

pub fn map_page(
    page: Page<Size4KiB>,
    frame: PhysFrame<Size4KiB>,
    flags: PageTableFlags,
) -> Result<(), &'static str>
Map a virtual page to a physical frame with the given flags.

Intermediate page tables are allocated from the buddy allocator as needed.