MemoryRegionRegistry

Struct MemoryRegionRegistry 

pub struct MemoryRegionRegistry { /* private fields */ }
Global registry for exported memory-region capabilities.

Implementations

Source

impl MemoryRegionRegistry

pub fn new() -> Self

Creates an empty memory-region registry.

pub fn export_region( &self, address_space: &AddressSpace, start: u64, handle_cap: CapId, ) -> Result<u64, RegionCapError>

Exports the tracked region starting at start into a public capability resource.

pub fn retain_handle( &self, resource_id: u64, handle_cap: CapId, ) -> Result<(), RegionCapError>

Adds one handle reference to an exported memory region.

pub fn info(&self, resource_id: u64) -> Option<PublicMemoryRegionInfo>

Returns public metadata about an exported memory region.

pub fn map_region( &self, resource_id: u64, address_space: &AddressSpace, addr_hint: u64, requested_flags: VmaFlags, ) -> Result<(u64, u64), RegionCapError>

Maps an exported memory region into address_space.

pub fn release_handle( &self, resource_id: u64, handle_cap: CapId, ) -> Result<ReleaseRegionResult, RegionCapError>

Releases one handle reference to an exported memory region.