pub struct TaskRef { /* private fields */ }Expand description
Reference-counted task handle
Similar to Theseus’s TaskRef, this provides safe reference counting for task structures.
Implementations
Sourceimpl TaskRef
impl TaskRef
Sourcepub unsafe fn new(task_ptr: *mut TaskInner) -> Self
pub unsafe fn new(task_ptr: *mut TaskInner) -> Self
Creates a new TaskRef from a raw task pointer
Safety
- The task_ptr must be valid for the lifetime of the process
- The caller must ensure proper synchronization
Sourcepub unsafe fn as_mut(&mut self) -> &mut TaskInner
pub unsafe fn as_mut(&mut self) -> &mut TaskInner
Returns a mutable reference to the inner task
Safety
The caller must ensure exclusive access to the task
Sourcepub fn is_last_ref(&self) -> bool
pub fn is_last_ref(&self) -> bool
Returns true if this is the last reference