fn load_elf_task_inner(
elf_data: &[u8],
name: &'static str,
extra_args: &[&str],
seed_caps: &[Capability],
) -> Result<Arc<Task>, &'static str>Expand description
Internal ELF task builder used by all public loading APIs.
extra_args are written to the user stack as argv[1..] after the program name.