pub fn finish_switch()Expand description
Called immediately after a context switch completes (in the new task’s context). This safely re-queues the previously running task now that its state is fully saved.
pub fn finish_switch()Called immediately after a context switch completes (in the new task’s context). This safely re-queues the previously running task now that its state is fully saved.