get_all_tasks

Function get_all_tasks 

pub fn get_all_tasks() -> Option<Vec<Arc<Task>>>
Get a list of all tasks in the system (for timer checking). Returns None if scheduler is not initialized or currently locked.