yield_task

Function yield_task 

pub fn yield_task()
Yield the current task to allow other tasks to run (cooperative).

Disables interrupts around the scheduler lock to prevent deadlock with the timer handler’s maybe_preempt().

Returns immediately (no-op) if preemption is disabled on this CPU.