struct SchedulerCpu {
class_rqs: PerCpuClassRqSet,
current_task: Option<Arc<Task>>,
current_runtime: CurrentRuntime,
idle_task: Arc<Task>,
task_to_requeue: Option<Arc<Task>>,
task_to_drop: Option<Arc<Task>>,
need_resched: bool,
class_table: SchedClassTable,
}Expand description
Per-CPU scheduler state
Fields
class_rqs: PerCpuClassRqSetMulti-class priority queues
current_task: Option<Arc<Task>>Currently running task
current_runtime: CurrentRuntimeCurrent runtime accounting
idle_task: Arc<Task>Idle task to run when no other tasks are ready
task_to_requeue: Option<Arc<Task>>Task that was just preempted and needs to be re-queued
task_to_drop: Option<Arc<Task>>Task that is dying or blocked, to drop outside the scheduler lock
need_resched: boolFlag indicating if the current task’s time slice has expired
class_table: SchedClassTableLocal copy of the class table for hot-path use without GLOBAL lock. Updated atomically when the global class table changes.