has_pending_signals

Function has_pending_signals 

pub fn has_pending_signals() -> bool
Check if the current task has any pending signals.

Used by blocking syscalls to determine if they should return EINTR.