CpuContext

Struct CpuContext 

#[repr(C)]
pub struct CpuContext { pub saved_rsp: u64, }
CPU context saved/restored during context switches.

Only stores the saved RSP. All callee-saved registers (rbx, rbp, r12-r15) are pushed onto the task’s kernel stack by switch_context().

Fields

saved_rsp: u64

Saved stack pointer (points into the task’s kernel stack)

Implementations

Source

impl CpuContext

pub fn new(entry_point: u64, kernel_stack: &KernelStack) -> Self

Create a new CPU context for a task starting at the given entry point.

Sets up a fake stack frame on the kernel stack that looks like switch_context() just pushed callee-saved registers. When switch_context() or restore_first_task() pops them and does ret, it will jump to task_entry_trampoline, which enables interrupts and jumps to the real entry point (stored in r12).

Stack layout (growing downward):

[stack_top]
  task_entry_trampoline   <- ret target
  0  (r15)
  0  (r14)
  0  (r13)
  entry_point (r12)      <- trampoline reads this
  0  (rbp)
  0  (rbx)
  <- saved_rsp points here