extern "C" fn busy_task_main() -> !Expand description
Main function for the busy-loop test task (never yields).
If preemption is working, this task will be forcibly interrupted by the timer and other tasks will still get CPU time. If preemption is broken, this task will starve everything else.
This task now runs for approximately 3-5 seconds then exits to allow keyboard input.