reclaim_kernel_user_stack

Function reclaim_kernel_user_stack 

pub fn reclaim_kernel_user_stack(task: &Arc<Task>)
Reclaim the kernel-owned user stack of task, if any.

Idempotent: the mapping is take()n from the task so repeated calls from both the exit path and the reap path are safe. Called from exit_current_task (normal exit) and cleanup_task_resources (forced kills / reaping).