cmd_nslookup

Function cmd_nslookup 

pub fn cmd_nslookup(args: &[String]) -> Result<(), ShellError>
Minimal DNS lookup command.

Reads the configured DNS servers and attempts a resolution via the /net/dns/resolve/<domain> scheme path. If the network strate does not yet support it, shows the configured nameservers and a TODO.