pub(super) fn cmd_test_exec_impl(_args: &[String]) -> Result<(), ShellError>Expand description
Launch the userspace exec regression test binary from initfs.
pub(super) fn cmd_test_exec_impl(_args: &[String]) -> Result<(), ShellError>Launch the userspace exec regression test binary from initfs.