pub(super) fn cmd_test_syscalls_impl(_args: &[String]) -> Result<(), ShellError>Expand description
Launch the userspace syscall integration test binary from initfs.
pub(super) fn cmd_test_syscalls_impl(_args: &[String]) -> Result<(), ShellError>Launch the userspace syscall integration test binary from initfs.