pub fn cmd_date(_args: &[String]) -> Result<(), ShellError>Expand description
Display the current kernel time.
Shows uptime-based time since boot and the nanosecond timestamp from the kernel clock source.
pub fn cmd_date(_args: &[String]) -> Result<(), ShellError>Display the current kernel time.
Shows uptime-based time since boot and the nanosecond timestamp from the kernel clock source.