pub fn cmd_watch(args: &[String]) -> Result<(), ShellError>Expand description
Execute a command repeatedly at a given interval.
Usage: watch <seconds> <command...>
Runs the specified command every N seconds until Ctrl+C.
pub fn cmd_watch(args: &[String]) -> Result<(), ShellError>Execute a command repeatedly at a given interval.
Usage: watch <seconds> <command...>
Runs the specified command every N seconds until Ctrl+C.