fn execute_line(line: &str, registry: &CommandRegistry)Expand description
Execute a command line, handling scripting, pipes and redirections.
fn execute_line(line: &str, registry: &CommandRegistry)Execute a command line, handling scripting, pipes and redirections.