run_line

Function run_line 

pub fn run_line(line: &str)
Execute one shell line without prompt/history handling.

This helper is used by commands such as watch to run another command through the same parser/executor pipeline.