take_pipe_input

Function take_pipe_input 

pub fn take_pipe_input() -> Option<Vec<u8>>
Take and return the current pipe input, if any.

Commands call this to consume piped data. Returns None when the command was not invoked as the right-hand side of a pipe.