pub fn enforce_cap_for_current_task(handle: u64) -> Result<(), SyscallError>Expand description
Enforce that the current task may use a delegated capability.
pub fn enforce_cap_for_current_task(handle: u64) -> Result<(), SyscallError>Enforce that the current task may use a delegated capability.