pub fn enforce_console_access() -> Result<(), SyscallError>Expand description
Enforce console access for the current task.
Only admin tasks or tasks holding a Console capability with write permission can access the kernel console (SYS_WRITE fd=1/2).