pub fn enforce_registry_bind_for_current_task() -> Result<(), SyscallError>Expand description
Performs the enforce registry bind for current task operation.
pub fn enforce_registry_bind_for_current_task() -> Result<(), SyscallError>Performs the enforce registry bind for current task operation.