grant_silo_admin_to_task

Function grant_silo_admin_to_task 

pub fn grant_silo_admin_to_task(task: &Arc<Task>) -> CapId
Grant the Silo Admin capability to a task (bootstrapping).

This should be called only for the initial admin task (e.g. “init”).