on_task_terminated

Function on_task_terminated 

pub fn on_task_terminated(task_id: TaskId)
Best-effort cleanup hook called by the scheduler when a task terminates.

Ensures task_to_silo mappings are removed even for normal exits and transitions a running/paused silo to Stopped when its last task is gone.