pub struct PreemptGuard {
_not_send: PhantomData<*mut ()>,
}Expand description
RAII guard that disables preemption on the current CPU.
Preemption is restored when this value is dropped.
Fields
_not_send: PhantomData<*mut ()>Marker to prevent Send : the guard must be dropped on the same CPU it was created on.
Implementations
Sourceimpl PreemptGuard
impl PreemptGuard