pub struct FixedQueue<T, const N: usize> {
entries: [MaybeUninit<T>; N],
head: usize,
len: usize,
}Expand description
Fixed-capacity FIFO queue with no heap allocation.
Fields
entries: [MaybeUninit<T>; N]head: usizelen: usizeImplementations
Sourceimpl<T, const N: usize> FixedQueue<T, N>
impl<T, const N: usize> FixedQueue<T, N>
Sourcepub fn get(&self, index: usize) -> Option<&T>
pub fn get(&self, index: usize) -> Option<&T>
Returns a shared reference to the element at index from the front.
Sourcepub fn iter(&self) -> FixedQueueIter<'_, T, N> ⓘ
pub fn iter(&self) -> FixedQueueIter<'_, T, N> ⓘ
Returns an iterator from front to back.
Sourcepub fn push_back(&mut self, value: T) -> Result<(), T>
pub fn push_back(&mut self, value: T) -> Result<(), T>
Appends an element to the tail of the queue.
Sourcepub fn pop_front(&mut self) -> Option<T>
pub fn pop_front(&mut self) -> Option<T>
Removes and returns the element at the head of the queue.
Sourcepub fn remove_first_where<F>(&mut self, predicate: F) -> Option<T>
pub fn remove_first_where<F>(&mut self, predicate: F) -> Option<T>
Removes the first element matching predicate.
fn remove_at(&mut self, offset: usize) -> T