FutexBucket

Struct FutexBucket 

struct FutexBucket {
    entries: [Option<FutexBucketEntry>; 32],
}

Fields

entries: [Option<FutexBucketEntry>; 32]

Implementations

Source

impl FutexBucket

const fn new() -> Self

fn lookup(&self, addr: u64) -> Option<Arc<FutexQueue>>

fn get_or_insert(&mut self, addr: u64) -> Result<Arc<FutexQueue>, SyscallError>

fn remove_if_empty(&mut self, addr: u64, queue: &Arc<FutexQueue>)

Removes the slot for addr/queue if the queue is still empty.

Lock ordering

This method is called while the bucket lock is held. It re-acquires queue.waiters internally to re-verify emptiness. Therefore the lock order on this path is:

bucket_lockqueue.waiters

Invariant: no code path may hold queue.waiters while trying to acquire any bucket_lock. Violating this would cause an ABBA deadlock with the ordering established here. All callers of queue.waiters.lock() in the syscall handlers release the bucket lock before acquiring waiters (bucket is released inside get_queue/ lookup_queue before the returned Arc is used).