pub fn sys_ipc_reply(msg_ptr: u64) -> Result<u64, SyscallError>Expand description
SYS_IPC_REPLY: send a reply to a caller that used SYS_IPC_CALL.
pub fn sys_ipc_reply(msg_ptr: u64) -> Result<u64, SyscallError>SYS_IPC_REPLY: send a reply to a caller that used SYS_IPC_CALL.