open_resolved

Function open_resolved 

fn open_resolved(path: &str, flags: OpenFlags) -> Result<u32, SyscallError>
Open a file with an already-resolved path (avoids double mount::resolve).

Used by sys_open and open_at which resolve the path once before calling this. The silo permission check must have already been performed.