pub struct Pipe { /* private fields */ }Expand description
Shared pipe handle.
Implementations
Sourceimpl Pipe
impl Pipe
Sourcepub fn read(&self, buf: &mut [u8]) -> Result<usize, SyscallError>
pub fn read(&self, buf: &mut [u8]) -> Result<usize, SyscallError>
Read from the pipe. Returns 0 on EOF (write end closed + empty).
Sourcepub fn write(&self, buf: &[u8]) -> Result<usize, SyscallError>
pub fn write(&self, buf: &[u8]) -> Result<usize, SyscallError>
Write to the pipe. Returns EPIPE if read end is closed.
Sourcepub fn close_read(&self) -> bool
pub fn close_read(&self) -> bool
Decrement the read-end refcount; marks the end closed only when it reaches zero. Returns true if the end was actually closed.
Sourcepub fn close_write(&self) -> bool
pub fn close_write(&self) -> bool
Decrement the write-end refcount; marks the end closed only when it reaches zero. Returns true if the end was actually closed.