pub struct OpenFlags(<OpenFlags as PublicFlags>::Internal);Expand description
File open flags for SYS_OPEN and SYS_OPENAT.
These are not POSIX O_* values. Use posix_oflags_to_strat9
to convert from POSIX flags when implementing a compatibility layer.
Tuple Fields
0: <OpenFlags as PublicFlags>::InternalImplementations
Sourceimpl OpenFlags
impl OpenFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<OpenFlags>
pub const fn from_bits(bits: u32) -> Option<OpenFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> OpenFlags
pub const fn from_bits_truncate(bits: u32) -> OpenFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> OpenFlags
pub const fn from_bits_retain(bits: u32) -> OpenFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<OpenFlags>
pub fn from_name(name: &str) -> Option<OpenFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: OpenFlags) -> bool
pub const fn intersects(&self, other: OpenFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: OpenFlags) -> bool
pub const fn contains(&self, other: OpenFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: OpenFlags)
pub fn remove(&mut self, other: OpenFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: OpenFlags)
pub fn toggle(&mut self, other: OpenFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: OpenFlags, value: bool)
pub fn set(&mut self, other: OpenFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: OpenFlags) -> OpenFlags
pub const fn intersection(self, other: OpenFlags) -> OpenFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: OpenFlags) -> OpenFlags
pub const fn union(self, other: OpenFlags) -> OpenFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: OpenFlags) -> OpenFlags
pub const fn difference(self, other: OpenFlags) -> OpenFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: OpenFlags) -> OpenFlags
pub const fn symmetric_difference(self, other: OpenFlags) -> OpenFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> OpenFlags
pub const fn complement(self) -> OpenFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl OpenFlags
impl OpenFlags
Sourcepub const fn iter(&self) -> Iter<OpenFlags>
pub const fn iter(&self) -> Iter<OpenFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<OpenFlags>
pub const fn iter_names(&self) -> IterNames<OpenFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.