Struct VirtAddrNotValid
pub struct VirtAddrNotValid(pub u64);Expand description
A passed u64 was not a valid virtual address.
This means that bits 48 to 64 are not a valid sign extension and are not null either. So automatic sign extension would have overwritten possibly meaningful bits. This likely indicates a bug, for example an invalid address calculation.
Contains the invalid address.
Tuple Fields
0: u64Trait Implementations