Function read_rip
pub fn read_rip() -> VirtAddrExpand description
Gets the current instruction pointer. Note that this is only approximate as it requires a few instructions to execute.
pub fn read_rip() -> VirtAddrGets the current instruction pointer. Note that this is only approximate as it requires a few instructions to execute.