Struct PortGeneric
pub struct PortGeneric<T, A> {
port: u16,
phantom: PhantomData<(T, A)>,
}Expand description
An I/O port.
The port reads or writes values of type T and has read/write access specified by A.
Use the provided marker types or aliases to get a port type with the access you need:
PortGeneric<T, ReadWriteAccess>->Port<T>PortGeneric<T, ReadOnlyAccess>->PortReadOnly<T>PortGeneric<T, WriteOnlyAccess>->PortWriteOnly<T>
Fields
port: u16phantom: PhantomData<(T, A)>Implementations
impl<T, A> PortGeneric<T, A>
impl<T, A> PortGeneric<T, A>
pub const fn new(port: u16) -> PortGeneric<T, A>
pub const fn new(port: u16) -> PortGeneric<T, A>
Creates an I/O port with the given port number.
impl<T, A> PortGeneric<T, A>where
T: PortRead,
A: PortReadAccess,
impl<T, A> PortGeneric<T, A>where
T: PortRead,
A: PortReadAccess,
impl<T, A> PortGeneric<T, A>where
T: PortWrite,
A: PortWriteAccess,
impl<T, A> PortGeneric<T, A>where
T: PortWrite,
A: PortWriteAccess,