Struct CS
pub struct CS;Expand description
Code Segment
While most fields in the Code-Segment [Descriptor] are unused in 64-bit
long mode, some of them must be set to a specific value. The
EXECUTABLE,
USER_SEGMENT, and
LONG_MODE bits must be set, while the
DEFAULT_SIZE bit must be unset.
The DPL_RING_3 field can be used to change
privilege level. The PRESENT bit can be used
to make a segment present or not present.
All other fields (like the segment base and limit) are ignored by the processor and setting them has no effect.