GS

pub struct GS;
GS Segment

Only base is used in 64-bit mode, see Segment64. In kernel-mode, the GS base often points to a per-cpu kernel data structure.

Implementations



impl GS

pub unsafe fn swap()

Swap KernelGsBase MSR and GsBase MSR.

Safety

This function is unsafe because the caller must ensure that the swap operation cannot lead to undefined behavior.