Struct SS
pub struct SS;Expand description
Stack Segment
Entirely unused in 64-bit mode; setting the segment register does nothing.
However, in ring 3, the SS register still has to point to a valid
[Descriptor] (it cannot be zero). This
means a user-mode read/write segment descriptor must be present in the GDT.
This register is also set by the syscall/sysret and
sysenter/sysexit instructions (even on 64-bit transitions). This is to
maintain symmetry with 32-bit transitions where setting SS actually will
actually have an effect.