Invlpgb

Struct Invlpgb 

pub struct Invlpgb {
    invlpgb_count_max: u16,
    tlb_flush_nested: bool,
    nasid: u32,
}
Used to broadcast flushes to all logical processors.

use x86_64::VirtAddr;
use x86_64::structures::paging::Page;
use x86_64::instructions::tlb::Invlpgb;

// Check that `invlpgb` and `tlbsync` are supported.
let invlpgb = Invlpgb::new().unwrap();

// Broadcast flushing some pages to all logical processors.
let start: Page = Page::from_start_address(VirtAddr::new(0xf000_0000)).unwrap();
let pages = Page::range(start, start + 3);
invlpgb.build().pages(pages).include_global().flush();

// Wait for all logical processors to respond.
invlpgb.tlbsync();

Fields

invlpgb_count_max: u16tlb_flush_nested: boolnasid: u32

Implementations



impl Invlpgb

pub fn new() -> Option<Invlpgb>

Check that invlpgb and tlbsync are supported and query limits.

Panics

Panics if the CPL is not 0.

pub fn invlpgb_count_max(&self) -> u16

Returns the maximum count of pages to be flushed supported by the processor.

pub fn tlb_flush_nested(&self) -> bool

Returns whether the processor supports flushing translations used for guest translation.

pub fn nasid(&self) -> u32

Returns the number of available address space identifiers.

pub fn build(&self) -> InvlpgbFlushBuilder<'_>

Create a InvlpgbFlushBuilder.

pub fn tlbsync(&self)

Wait for all previous invlpgb instruction executed on the current logical processor to be acknowledged by all other logical processors.