Struct InvlpgbFlushBuilder
pub struct InvlpgbFlushBuilder<'a, S = Size4KiB>where
S: NotGiantPageSize,{
invlpgb: &'a Invlpgb,
page_range: Option<PageRange<S>>,
pcid: Option<Pcid>,
asid: Option<u16>,
include_global: bool,
final_translation_only: bool,
include_nested_translations: bool,
}Expand description
A builder struct to construct the parameters for the invlpgb instruction.
Fields
invlpgb: &'a Invlpgbpage_range: Option<PageRange<S>>pcid: Option<Pcid>asid: Option<u16>include_global: boolfinal_translation_only: boolinclude_nested_translations: boolImplementations
impl<'a, S> InvlpgbFlushBuilder<'a, S>where
S: NotGiantPageSize,
impl<'a, S> InvlpgbFlushBuilder<'a, S>where
S: NotGiantPageSize,
pub fn pages<T>(self, page_range: PageRange<T>) -> InvlpgbFlushBuilder<'a, T>where
T: NotGiantPageSize,
pub fn pages<T>(self, page_range: PageRange<T>) -> InvlpgbFlushBuilder<'a, T>where
T: NotGiantPageSize,
Flush a range of pages.
If the range doesn’t fit within invlpgb_count_max, invlpgb is
executed multiple times.
pub unsafe fn pcid(&mut self, pcid: Pcid) -> &mut InvlpgbFlushBuilder<'a, S>
pub unsafe fn pcid(&mut self, pcid: Pcid) -> &mut InvlpgbFlushBuilder<'a, S>
Only flush TLB entries with the given PCID.
Safety
The caller has to ensure that PCID is enabled in CR4 when the flush is executed.
pub unsafe fn asid(
&mut self,
asid: u16,
) -> Result<&mut InvlpgbFlushBuilder<'a, S>, AsidOutOfRangeError>
pub unsafe fn asid( &mut self, asid: u16, ) -> Result<&mut InvlpgbFlushBuilder<'a, S>, AsidOutOfRangeError>
Only flush TLB entries with the given ASID.
Safety
The caller has to ensure that SVM is enabled in EFER when the flush is executed.
pub fn include_global(&mut self) -> &mut InvlpgbFlushBuilder<'a, S>
pub fn include_global(&mut self) -> &mut InvlpgbFlushBuilder<'a, S>
Also flush global pages.
pub fn final_translation_only(&mut self) -> &mut InvlpgbFlushBuilder<'a, S>
pub fn final_translation_only(&mut self) -> &mut InvlpgbFlushBuilder<'a, S>
Only flush the final translation and not the cached upper level TLB entries.
pub fn include_nested_translations(self) -> InvlpgbFlushBuilder<'a, S>
pub fn include_nested_translations(self) -> InvlpgbFlushBuilder<'a, S>
Also flush nestred translations that could be used for guest translation.
pub fn flush(&self)
pub fn flush(&self)
Execute the flush.