Cr0

Struct Cr0 

pub struct Cr0;
Various control flags modifying the basic operation of the CPU.

Implementations



impl Cr0

pub fn read() -> Cr0Flags

Read the current set of CR0 flags.

pub fn read_raw() -> u64

Read the current raw CR0 value.

pub unsafe fn write(flags: Cr0Flags)

Write CR0 flags.

Preserves the value of reserved fields.

Safety

This function is unsafe because it’s possible to violate memory safety through it, e.g. by disabling paging.

pub unsafe fn write_raw(value: u64)

Write raw CR0 flags.

Does not preserve any values, including reserved fields.

Safety

This function is unsafe because it’s possible to violate memory safety through it, e.g. by disabling paging.

pub unsafe fn update<F>(f: F)
where F: FnOnce(&mut Cr0Flags),

Updates CR0 flags.

Preserves the value of reserved fields.

Safety

This function is unsafe because it’s possible to violate memory safety through it, e.g. by disabling paging.