Struct Cr0Flags
#[repr(transparent)]pub struct Cr0Flags(<Cr0Flags as PublicFlags>::Internal);Expand description
Configuration flags of the Cr0 register.
Tuple Fields
0: <Cr0Flags as PublicFlags>::InternalImplementations
impl Cr0Flags
impl Cr0Flags
pub const PROTECTED_MODE_ENABLE: Cr0Flags
pub const PROTECTED_MODE_ENABLE: Cr0Flags
Enables protected mode.
pub const MONITOR_COPROCESSOR: Cr0Flags
pub const MONITOR_COPROCESSOR: Cr0Flags
Enables monitoring of the coprocessor, typical for x87 instructions.
Controls (together with the TASK_SWITCHED
flag) whether a wait or fwait instruction should cause an #NE exception.
pub const EMULATE_COPROCESSOR: Cr0Flags
pub const EMULATE_COPROCESSOR: Cr0Flags
Force all x87 and MMX instructions to cause an #NE exception.
pub const TASK_SWITCHED: Cr0Flags
pub const TASK_SWITCHED: Cr0Flags
Automatically set to 1 on hardware task switch.
This flags allows lazily saving x87/MMX/SSE instructions on hardware context switches.
pub const EXTENSION_TYPE: Cr0Flags
pub const EXTENSION_TYPE: Cr0Flags
Indicates support of 387DX math coprocessor instructions.
Always set on all recent x86 processors, cannot be cleared.
pub const NUMERIC_ERROR: Cr0Flags
pub const NUMERIC_ERROR: Cr0Flags
Enables the native (internal) error reporting mechanism for x87 FPU errors.
pub const WRITE_PROTECT: Cr0Flags
pub const WRITE_PROTECT: Cr0Flags
Controls whether supervisor-level writes to read-only pages are inhibited.
When set, it is not possible to write to read-only pages from ring 0.
pub const ALIGNMENT_MASK: Cr0Flags
pub const ALIGNMENT_MASK: Cr0Flags
Enables automatic usermode alignment checking if [RFlags::ALIGNMENT_CHECK] is also set.
pub const NOT_WRITE_THROUGH: Cr0Flags
pub const NOT_WRITE_THROUGH: Cr0Flags
Ignored, should always be unset.
Must be unset if CACHE_DISABLE is unset.
Older CPUs used this to control write-back/write-through cache strategy.
pub const CACHE_DISABLE: Cr0Flags
pub const CACHE_DISABLE: Cr0Flags
Disables some processor caches, specifics are model-dependent.
pub const PAGING: Cr0Flags
pub const PAGING: Cr0Flags
Enables paging.
If this bit is set, PROTECTED_MODE_ENABLE must be set.
impl Cr0Flags
impl Cr0Flags
pub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u64) -> Option<Cr0Flags>
pub const fn from_bits(bits: u64) -> Option<Cr0Flags>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u64) -> Cr0Flags
pub const fn from_bits_truncate(bits: u64) -> Cr0Flags
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u64) -> Cr0Flags
pub const fn from_bits_retain(bits: u64) -> Cr0Flags
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<Cr0Flags>
pub fn from_name(name: &str) -> Option<Cr0Flags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: Cr0Flags) -> bool
pub const fn intersects(&self, other: Cr0Flags) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: Cr0Flags) -> bool
pub const fn contains(&self, other: Cr0Flags) -> bool
Whether all set bits in other are also set in self.
pub fn remove(&mut self, other: Cr0Flags)
pub fn remove(&mut self, other: Cr0Flags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: Cr0Flags)
pub fn toggle(&mut self, other: Cr0Flags)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: Cr0Flags, value: bool)
pub fn set(&mut self, other: Cr0Flags, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: Cr0Flags) -> Cr0Flags
pub const fn intersection(self, other: Cr0Flags) -> Cr0Flags
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: Cr0Flags) -> Cr0Flags
pub const fn union(self, other: Cr0Flags) -> Cr0Flags
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: Cr0Flags) -> Cr0Flags
pub const fn difference(self, other: Cr0Flags) -> Cr0Flags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: Cr0Flags) -> Cr0Flags
pub const fn symmetric_difference(self, other: Cr0Flags) -> Cr0Flags
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> Cr0Flags
pub const fn complement(self) -> Cr0Flags
The bitwise negation (!) of the bits in self, truncating the result.
impl Cr0Flags
impl Cr0Flags
pub const fn iter(&self) -> Iter<Cr0Flags> ⓘ
pub const fn iter(&self) -> Iter<Cr0Flags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<Cr0Flags> ⓘ
pub const fn iter_names(&self) -> IterNames<Cr0Flags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.