Struct Cr4
pub struct Cr4;Expand description
Contains various control flags that enable architectural extensions, and indicate support for specific processor capabilities.
Implementations
impl Cr4
impl Cr4
pub unsafe fn write(flags: Cr4Flags)
pub unsafe fn write(flags: Cr4Flags)
Write CR4 flags.
Preserves the value of reserved fields.
Safety
This function is unsafe because it’s possible to violate memory safety through it, e.g. by overwriting the physical address extension flag.