Struct EferFlags
#[repr(transparent)]pub struct EferFlags(<EferFlags as PublicFlags>::Internal);Expand description
Flags of the Extended Feature Enable Register.
Tuple Fields
0: <EferFlags as PublicFlags>::InternalImplementations
impl EferFlags
impl EferFlags
pub const SYSTEM_CALL_EXTENSIONS: EferFlags
pub const SYSTEM_CALL_EXTENSIONS: EferFlags
Enables the syscall and sysret instructions.
pub const LONG_MODE_ENABLE: EferFlags
pub const LONG_MODE_ENABLE: EferFlags
Activates long mode, requires activating paging.
pub const LONG_MODE_ACTIVE: EferFlags
pub const LONG_MODE_ACTIVE: EferFlags
Indicates that long mode is active.
pub const NO_EXECUTE_ENABLE: EferFlags
pub const NO_EXECUTE_ENABLE: EferFlags
Enables the no-execute page-protection feature.
pub const SECURE_VIRTUAL_MACHINE_ENABLE: EferFlags
pub const SECURE_VIRTUAL_MACHINE_ENABLE: EferFlags
Enables SVM extensions.
pub const LONG_MODE_SEGMENT_LIMIT_ENABLE: EferFlags
pub const LONG_MODE_SEGMENT_LIMIT_ENABLE: EferFlags
Enable certain limit checks in 64-bit mode.
pub const FAST_FXSAVE_FXRSTOR: EferFlags
pub const FAST_FXSAVE_FXRSTOR: EferFlags
Enable the fxsave and fxrstor instructions to execute faster in 64-bit mode.
pub const TRANSLATION_CACHE_EXTENSION: EferFlags
pub const TRANSLATION_CACHE_EXTENSION: EferFlags
Changes how the invlpg instruction operates on TLB entries of upper-level entries.
impl EferFlags
impl EferFlags
pub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u64) -> Option<EferFlags>
pub const fn from_bits(bits: u64) -> Option<EferFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u64) -> EferFlags
pub const fn from_bits_truncate(bits: u64) -> EferFlags
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u64) -> EferFlags
pub const fn from_bits_retain(bits: u64) -> EferFlags
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<EferFlags>
pub fn from_name(name: &str) -> Option<EferFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: EferFlags) -> bool
pub const fn intersects(&self, other: EferFlags) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: EferFlags) -> bool
pub const fn contains(&self, other: EferFlags) -> bool
Whether all set bits in other are also set in self.
pub fn remove(&mut self, other: EferFlags)
pub fn remove(&mut self, other: EferFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: EferFlags)
pub fn toggle(&mut self, other: EferFlags)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: EferFlags, value: bool)
pub fn set(&mut self, other: EferFlags, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: EferFlags) -> EferFlags
pub const fn intersection(self, other: EferFlags) -> EferFlags
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: EferFlags) -> EferFlags
pub const fn union(self, other: EferFlags) -> EferFlags
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: EferFlags) -> EferFlags
pub const fn difference(self, other: EferFlags) -> EferFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: EferFlags) -> EferFlags
pub const fn symmetric_difference(self, other: EferFlags) -> EferFlags
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> EferFlags
pub const fn complement(self) -> EferFlags
The bitwise negation (!) of the bits in self, truncating the result.
impl EferFlags
impl EferFlags
pub const fn iter(&self) -> Iter<EferFlags> ⓘ
pub const fn iter(&self) -> Iter<EferFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<EferFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<EferFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.