Enum BreakpointSize
#[repr(u8)]pub enum BreakpointSize {
Length1B = 0,
Length2B = 1,
Length8B = 2,
Length4B = 3,
}Expand description
The size of a hardware breakpoint.
Variants
Length1B = 0
1 byte length
Length2B = 1
2 byte length
Length8B = 2
8 byte length
Length4B = 3
4 byte length
Implementations
impl BreakpointSize
impl BreakpointSize
pub const fn new(size: usize) -> Option<BreakpointSize>
pub const fn new(size: usize) -> Option<BreakpointSize>
Creates a new hardware breakpoint size if size is valid.
pub const fn from_bits(bits: u64) -> Option<BreakpointSize>
pub const fn from_bits(bits: u64) -> Option<BreakpointSize>
Creates a new hardware breakpoint size if bits is valid.