Struct Dr6Flags
#[repr(transparent)]pub struct Dr6Flags(<Dr6Flags as PublicFlags>::Internal);Expand description
Debug condition flags of the Dr6 register.
Tuple Fields
0: <Dr6Flags as PublicFlags>::InternalImplementations
impl Dr6Flags
impl Dr6Flags
pub const ACCESS_DETECTED: Dr6Flags
pub const ACCESS_DETECTED: Dr6Flags
Next instruction accesses one of the debug registers.
Enabled via Dr7Flags::GENERAL_DETECT_ENABLE.
pub const SWITCH: Dr6Flags
pub const SWITCH: Dr6Flags
Task switch.
Enabled via the debug trap flag in the TSS of the target task.
pub const RTM: Dr6Flags
pub const RTM: Dr6Flags
When clear, indicates a debug or breakpoint exception inside an RTM region.
Enabled via Dr7Flags::RESTRICTED_TRANSACTIONAL_MEMORY and the
RTM flag in the IA32_DEBUGCTL [Msr].
impl Dr6Flags
impl Dr6Flags
pub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u64) -> Option<Dr6Flags>
pub const fn from_bits(bits: u64) -> Option<Dr6Flags>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u64) -> Dr6Flags
pub const fn from_bits_truncate(bits: u64) -> Dr6Flags
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u64) -> Dr6Flags
pub const fn from_bits_retain(bits: u64) -> Dr6Flags
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<Dr6Flags>
pub fn from_name(name: &str) -> Option<Dr6Flags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: Dr6Flags) -> bool
pub const fn intersects(&self, other: Dr6Flags) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: Dr6Flags) -> bool
pub const fn contains(&self, other: Dr6Flags) -> bool
Whether all set bits in other are also set in self.
pub fn remove(&mut self, other: Dr6Flags)
pub fn remove(&mut self, other: Dr6Flags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: Dr6Flags)
pub fn toggle(&mut self, other: Dr6Flags)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: Dr6Flags, value: bool)
pub fn set(&mut self, other: Dr6Flags, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: Dr6Flags) -> Dr6Flags
pub const fn intersection(self, other: Dr6Flags) -> Dr6Flags
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: Dr6Flags) -> Dr6Flags
pub const fn union(self, other: Dr6Flags) -> Dr6Flags
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: Dr6Flags) -> Dr6Flags
pub const fn difference(self, other: Dr6Flags) -> Dr6Flags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: Dr6Flags) -> Dr6Flags
pub const fn symmetric_difference(self, other: Dr6Flags) -> Dr6Flags
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> Dr6Flags
pub const fn complement(self) -> Dr6Flags
The bitwise negation (!) of the bits in self, truncating the result.
impl Dr6Flags
impl Dr6Flags
pub const fn iter(&self) -> Iter<Dr6Flags> ⓘ
pub const fn iter(&self) -> Iter<Dr6Flags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<Dr6Flags> ⓘ
pub const fn iter_names(&self) -> IterNames<Dr6Flags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
impl Dr6Flags
impl Dr6Flags
pub fn trap(n: DebugAddressRegisterNumber) -> Dr6Flags
pub fn trap(n: DebugAddressRegisterNumber) -> Dr6Flags
Returns the trap flag of the provided debug address register.