Dr7Value

Struct Dr7Value 

#[repr(transparent)]
pub struct Dr7Value { bits: u64, }
A valid value of the Dr7 debug register.

In addition to the Dr7Flags this value has a condition field and a size field for each debug address register.

Fields

bits: u64

Implementations



impl Dr7Value

pub const fn from_bits(bits: u64) -> Option<Dr7Value>

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a field.

pub const fn from_bits_truncate(bits: u64) -> Dr7Value

Convert from underlying bit representation, dropping any bits that do not correspond to fields.

pub const unsafe fn from_bits_unchecked(bits: u64) -> Dr7Value

Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined field).

Safety

The bit representation must be a valid Dr7Value.

pub const fn bits(&self) -> u64

Returns the raw value of the fields currently stored.

pub const fn flags(self) -> Dr7Flags

Returns the Dr7Flags in this value.

pub fn insert_flags(&mut self, flags: Dr7Flags)

Inserts the specified Dr7Flags in-place.

pub fn remove_flags(&mut self, flags: Dr7Flags)

Removes the specified Dr7Flags in-place.

pub fn toggle_flags(&mut self, flags: Dr7Flags)

Toggles the specified Dr7Flags in-place.

pub fn set_flags(&mut self, flags: Dr7Flags, value: bool)

Inserts or removes the specified Dr7Flags depending on the passed value.

pub fn condition(&self, n: DebugAddressRegisterNumber) -> BreakpointCondition

Returns the condition field of a debug address register.

pub fn set_condition( &mut self, n: DebugAddressRegisterNumber, condition: BreakpointCondition, )

Sets the condition field of a debug address register.

pub fn size(&self, n: DebugAddressRegisterNumber) -> BreakpointSize

Returns the size field of a debug address register.

pub fn set_size(&mut self, n: DebugAddressRegisterNumber, size: BreakpointSize)

Sets the size field of a debug address register.