Struct ApicBaseFlags
#[repr(transparent)]pub struct ApicBaseFlags(<ApicBaseFlags as PublicFlags>::Internal);Expand description
Flags for the Advanced Programmable Interrupt Controller Base Register.
Tuple Fields
0: <ApicBaseFlags as PublicFlags>::InternalImplementations
impl ApicBaseFlags
impl ApicBaseFlags
pub const BSP: ApicBaseFlags
pub const BSP: ApicBaseFlags
Indicates whether the current processor is the bootstrap processor
pub const X2APIC_ENABLE: ApicBaseFlags
pub const X2APIC_ENABLE: ApicBaseFlags
Places the local APIC in the x2APIC mode. Processor support for x2APIC feature can be
detected using the cpuid instruction. (CPUID.(EAX=1):ECX.21)
pub const LAPIC_ENABLE: ApicBaseFlags
pub const LAPIC_ENABLE: ApicBaseFlags
Enables or disables the local Apic
impl ApicBaseFlags
impl ApicBaseFlags
pub const fn empty() -> ApicBaseFlags
pub const fn empty() -> ApicBaseFlags
Get a flags value with all bits unset.
pub const fn all() -> ApicBaseFlags
pub const fn all() -> ApicBaseFlags
Get a flags value with all known bits set.
pub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u64) -> Option<ApicBaseFlags>
pub const fn from_bits(bits: u64) -> Option<ApicBaseFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u64) -> ApicBaseFlags
pub const fn from_bits_truncate(bits: u64) -> ApicBaseFlags
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u64) -> ApicBaseFlags
pub const fn from_bits_retain(bits: u64) -> ApicBaseFlags
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<ApicBaseFlags>
pub fn from_name(name: &str) -> Option<ApicBaseFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: ApicBaseFlags) -> bool
pub const fn intersects(&self, other: ApicBaseFlags) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: ApicBaseFlags) -> bool
pub const fn contains(&self, other: ApicBaseFlags) -> bool
Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: ApicBaseFlags)
pub fn insert(&mut self, other: ApicBaseFlags)
The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: ApicBaseFlags)
pub fn remove(&mut self, other: ApicBaseFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: ApicBaseFlags)
pub fn toggle(&mut self, other: ApicBaseFlags)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: ApicBaseFlags, value: bool)
pub fn set(&mut self, other: ApicBaseFlags, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: ApicBaseFlags) -> ApicBaseFlags
pub const fn intersection(self, other: ApicBaseFlags) -> ApicBaseFlags
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: ApicBaseFlags) -> ApicBaseFlags
pub const fn union(self, other: ApicBaseFlags) -> ApicBaseFlags
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: ApicBaseFlags) -> ApicBaseFlags
pub const fn difference(self, other: ApicBaseFlags) -> ApicBaseFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: ApicBaseFlags) -> ApicBaseFlags
pub const fn symmetric_difference(self, other: ApicBaseFlags) -> ApicBaseFlags
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> ApicBaseFlags
pub const fn complement(self) -> ApicBaseFlags
The bitwise negation (!) of the bits in self, truncating the result.
impl ApicBaseFlags
impl ApicBaseFlags
pub const fn iter(&self) -> Iter<ApicBaseFlags> ⓘ
pub const fn iter(&self) -> Iter<ApicBaseFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<ApicBaseFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<ApicBaseFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.