Struct CetFlags
#[repr(transparent)]pub struct CetFlags(<CetFlags as PublicFlags>::Internal);Expand description
Flags stored in IA32_U_CET and IA32_S_CET (Table-2-2 in Intel SDM Volume 4). The Intel SDM-equivalent names are described in parentheses.
Tuple Fields
0: <CetFlags as PublicFlags>::InternalImplementations
impl CetFlags
impl CetFlags
pub const SS_WRITE_ENABLE: CetFlags
pub const SS_WRITE_ENABLE: CetFlags
Enable WRSS{D,Q}W instructions (WR_SHTK_EN)
pub const IBT_ENABLE: CetFlags
pub const IBT_ENABLE: CetFlags
Enable indirect branch tracking (ENDBR_EN)
pub const IBT_LEGACY_ENABLE: CetFlags
pub const IBT_LEGACY_ENABLE: CetFlags
Enable legacy treatment for indirect branch tracking (LEG_IW_EN)
pub const IBT_NO_TRACK_ENABLE: CetFlags
pub const IBT_NO_TRACK_ENABLE: CetFlags
Enable no-track opcode prefix for indirect branch tracking (NO_TRACK_EN)
pub const IBT_LEGACY_SUPPRESS_ENABLE: CetFlags
pub const IBT_LEGACY_SUPPRESS_ENABLE: CetFlags
Disable suppression of CET on legacy compatibility (SUPPRESS_DIS)
pub const IBT_SUPPRESS_ENABLE: CetFlags
pub const IBT_SUPPRESS_ENABLE: CetFlags
Enable suppression of indirect branch tracking (SUPPRESS)
pub const IBT_TRACKED: CetFlags
pub const IBT_TRACKED: CetFlags
Is IBT waiting for a branch to return? (read-only, TRACKER)
impl CetFlags
impl CetFlags
pub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u64) -> Option<CetFlags>
pub const fn from_bits(bits: u64) -> Option<CetFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u64) -> CetFlags
pub const fn from_bits_truncate(bits: u64) -> CetFlags
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u64) -> CetFlags
pub const fn from_bits_retain(bits: u64) -> CetFlags
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<CetFlags>
pub fn from_name(name: &str) -> Option<CetFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: CetFlags) -> bool
pub const fn intersects(&self, other: CetFlags) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: CetFlags) -> bool
pub const fn contains(&self, other: CetFlags) -> bool
Whether all set bits in other are also set in self.
pub fn remove(&mut self, other: CetFlags)
pub fn remove(&mut self, other: CetFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: CetFlags)
pub fn toggle(&mut self, other: CetFlags)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: CetFlags, value: bool)
pub fn set(&mut self, other: CetFlags, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: CetFlags) -> CetFlags
pub const fn intersection(self, other: CetFlags) -> CetFlags
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: CetFlags) -> CetFlags
pub const fn union(self, other: CetFlags) -> CetFlags
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: CetFlags) -> CetFlags
pub const fn difference(self, other: CetFlags) -> CetFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: CetFlags) -> CetFlags
pub const fn symmetric_difference(self, other: CetFlags) -> CetFlags
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> CetFlags
pub const fn complement(self) -> CetFlags
The bitwise negation (!) of the bits in self, truncating the result.
impl CetFlags
impl CetFlags
pub const fn iter(&self) -> Iter<CetFlags> ⓘ
pub const fn iter(&self) -> Iter<CetFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<CetFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<CetFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.