Efer

pub struct Efer;
The Extended Feature Enable Register.

Implementations



impl Efer

pub const MSR: Msr

The underlying model specific register.



impl Efer

pub fn read() -> EferFlags

Read the current EFER flags.

pub fn read_raw() -> u64

Read the current raw EFER flags.

pub unsafe fn write(flags: EferFlags)

Write the EFER flags, preserving reserved values.

Preserves the value of reserved fields.

Safety

Unsafe because it’s possible to break memory safety with wrong flags, e.g. by disabling long mode.

pub unsafe fn write_raw(flags: u64)

Write the EFER flags.

Does not preserve any bits, including reserved fields.

Safety

Unsafe because it’s possible to break memory safety with wrong flags, e.g. by disabling long mode.

pub unsafe fn update<F>(f: F)
where F: FnOnce(&mut EferFlags),

Update EFER flags.

Preserves the value of reserved fields.

Safety

Unsafe because it’s possible to break memory safety with wrong flags, e.g. by disabling long mode.