Struct MxCsr
#[repr(transparent)]pub struct MxCsr(<MxCsr as PublicFlags>::Internal);Expand description
MXCSR register.
Tuple Fields
0: <MxCsr as PublicFlags>::InternalImplementations
impl MxCsr
impl MxCsr
pub const INVALID_OPERATION: MxCsr
pub const INVALID_OPERATION: MxCsr
Invalid operation
pub const DIVIDE_BY_ZERO: MxCsr
pub const DIVIDE_BY_ZERO: MxCsr
Divide-by-zero
pub const DENORMALS_ARE_ZEROS: MxCsr
pub const DENORMALS_ARE_ZEROS: MxCsr
Denormals are zeros
pub const INVALID_OPERATION_MASK: MxCsr
pub const INVALID_OPERATION_MASK: MxCsr
Invalid operation mask
pub const DENORMAL_MASK: MxCsr
pub const DENORMAL_MASK: MxCsr
Denormal mask
pub const DIVIDE_BY_ZERO_MASK: MxCsr
pub const DIVIDE_BY_ZERO_MASK: MxCsr
Divide-by-zero mask
pub const OVERFLOW_MASK: MxCsr
pub const OVERFLOW_MASK: MxCsr
Overflow mask
pub const UNDERFLOW_MASK: MxCsr
pub const UNDERFLOW_MASK: MxCsr
Underflow mask
pub const PRECISION_MASK: MxCsr
pub const PRECISION_MASK: MxCsr
Precision mask
pub const ROUNDING_CONTROL_NEGATIVE: MxCsr
pub const ROUNDING_CONTROL_NEGATIVE: MxCsr
Toward negative infinity
pub const ROUNDING_CONTROL_POSITIVE: MxCsr
pub const ROUNDING_CONTROL_POSITIVE: MxCsr
Toward positive infinity
pub const ROUNDING_CONTROL_ZERO: MxCsr
pub const ROUNDING_CONTROL_ZERO: MxCsr
Toward zero (positive + negative)
pub const FLUSH_TO_ZERO: MxCsr
pub const FLUSH_TO_ZERO: MxCsr
Flush to zero
impl MxCsr
impl MxCsr
pub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<MxCsr>
pub const fn from_bits(bits: u32) -> Option<MxCsr>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> MxCsr
pub const fn from_bits_truncate(bits: u32) -> MxCsr
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> MxCsr
pub const fn from_bits_retain(bits: u32) -> MxCsr
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<MxCsr>
pub fn from_name(name: &str) -> Option<MxCsr>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: MxCsr) -> bool
pub const fn intersects(&self, other: MxCsr) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: MxCsr) -> bool
pub const fn contains(&self, other: MxCsr) -> bool
Whether all set bits in other are also set in self.
pub fn remove(&mut self, other: MxCsr)
pub fn remove(&mut self, other: MxCsr)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn set(&mut self, other: MxCsr, value: bool)
pub fn set(&mut self, other: MxCsr, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: MxCsr) -> MxCsr
pub const fn intersection(self, other: MxCsr) -> MxCsr
The bitwise and (&) of the bits in self and other.
pub const fn difference(self, other: MxCsr) -> MxCsr
pub const fn difference(self, other: MxCsr) -> MxCsr
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: MxCsr) -> MxCsr
pub const fn symmetric_difference(self, other: MxCsr) -> MxCsr
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> MxCsr
pub const fn complement(self) -> MxCsr
The bitwise negation (!) of the bits in self, truncating the result.
impl MxCsr
impl MxCsr
pub const fn iter(&self) -> Iter<MxCsr> ⓘ
pub const fn iter(&self) -> Iter<MxCsr> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<MxCsr> ⓘ
pub const fn iter_names(&self) -> IterNames<MxCsr> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.