Struct RFlags
#[repr(transparent)]pub struct RFlags(<RFlags as PublicFlags>::Internal);Expand description
The RFLAGS register. All bit patterns are valid representations for this type.
Tuple Fields
0: <RFlags as PublicFlags>::InternalImplementations
impl RFlags
impl RFlags
pub const ID: RFlags
pub const ID: RFlags
Processor feature identification flag.
If this flag is modifiable, the CPU supports CPUID.
pub const VIRTUAL_INTERRUPT_PENDING: RFlags
pub const VIRTUAL_INTERRUPT_PENDING: RFlags
Indicates that an external, maskable interrupt is pending.
Used when virtual-8086 mode extensions (CR4.VME) or protected-mode virtual interrupts (CR4.PVI) are activated.
pub const VIRTUAL_INTERRUPT: RFlags
pub const VIRTUAL_INTERRUPT: RFlags
Virtual image of the INTERRUPT_FLAG bit.
Used when virtual-8086 mode extensions (CR4.VME) or protected-mode virtual interrupts (CR4.PVI) are activated.
pub const ALIGNMENT_CHECK: RFlags
pub const ALIGNMENT_CHECK: RFlags
Enable automatic alignment checking if CR0.AM is set. Only works if CPL is 3.
pub const VIRTUAL_8086_MODE: RFlags
pub const VIRTUAL_8086_MODE: RFlags
Enable the virtual-8086 mode.
pub const RESUME_FLAG: RFlags
pub const RESUME_FLAG: RFlags
Allows to restart an instruction following an instruction breakpoint.
pub const NESTED_TASK: RFlags
pub const NESTED_TASK: RFlags
Used by iret in hardware task switch mode to determine if current task is nested.
pub const IOPL_HIGH: RFlags
pub const IOPL_HIGH: RFlags
The high bit of the I/O Privilege Level field.
Specifies the privilege level required for executing I/O address-space instructions.
pub const IOPL_LOW: RFlags
pub const IOPL_LOW: RFlags
The low bit of the I/O Privilege Level field.
Specifies the privilege level required for executing I/O address-space instructions.
pub const OVERFLOW_FLAG: RFlags
pub const OVERFLOW_FLAG: RFlags
Set by hardware to indicate that the sign bit of the result of the last signed integer operation differs from the source operands.
pub const DIRECTION_FLAG: RFlags
pub const DIRECTION_FLAG: RFlags
Determines the order in which strings are processed.
pub const INTERRUPT_FLAG: RFlags
pub const INTERRUPT_FLAG: RFlags
Enable interrupts.
pub const SIGN_FLAG: RFlags
pub const SIGN_FLAG: RFlags
Set by hardware if last arithmetic operation resulted in a negative value.
pub const AUXILIARY_CARRY_FLAG: RFlags
pub const AUXILIARY_CARRY_FLAG: RFlags
Set by hardware if last arithmetic operation generated a carry ouf of bit 3 of the result.
pub const PARITY_FLAG: RFlags
pub const PARITY_FLAG: RFlags
Set by hardware if last result has an even number of 1 bits (only for some operations).
pub const CARRY_FLAG: RFlags
pub const CARRY_FLAG: RFlags
Set by hardware if last arithmetic operation generated a carry out of the most-significant bit of the result.
impl RFlags
impl RFlags
pub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u64) -> Option<RFlags>
pub const fn from_bits(bits: u64) -> Option<RFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u64) -> RFlags
pub const fn from_bits_truncate(bits: u64) -> RFlags
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u64) -> RFlags
pub const fn from_bits_retain(bits: u64) -> RFlags
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<RFlags>
pub fn from_name(name: &str) -> Option<RFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: RFlags) -> bool
pub const fn intersects(&self, other: RFlags) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: RFlags) -> bool
pub const fn contains(&self, other: RFlags) -> bool
Whether all set bits in other are also set in self.
pub fn remove(&mut self, other: RFlags)
pub fn remove(&mut self, other: RFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn set(&mut self, other: RFlags, value: bool)
pub fn set(&mut self, other: RFlags, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: RFlags) -> RFlags
pub const fn intersection(self, other: RFlags) -> RFlags
The bitwise and (&) of the bits in self and other.
pub const fn difference(self, other: RFlags) -> RFlags
pub const fn difference(self, other: RFlags) -> RFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: RFlags) -> RFlags
pub const fn symmetric_difference(self, other: RFlags) -> RFlags
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> RFlags
pub const fn complement(self) -> RFlags
The bitwise negation (!) of the bits in self, truncating the result.
impl RFlags
impl RFlags
pub const fn iter(&self) -> Iter<RFlags> ⓘ
pub const fn iter(&self) -> Iter<RFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<RFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<RFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.