Struct SegmentSelector
#[repr(transparent)]pub struct SegmentSelector(pub u16);Expand description
Specifies which element to load into a segment from descriptor tables (i.e., is a index to LDT or GDT table with some additional flags).
See Intel 3a, Section 3.4.2 “Segment Selectors”
Tuple Fields
0: u16Implementations
impl SegmentSelector
impl SegmentSelector
pub const NULL: SegmentSelector
pub const NULL: SegmentSelector
Can be used as a selector into a non-existent segment and assigned to segment registers, e.g. data segment register in ring 0
pub const fn new(index: u16, rpl: PrivilegeLevel) -> SegmentSelector
pub const fn new(index: u16, rpl: PrivilegeLevel) -> SegmentSelector
Creates a new SegmentSelector
Arguments
index: index in GDT or LDT array (not the offset)rpl: the requested privilege level
pub fn rpl(self) -> PrivilegeLevel
pub fn rpl(self) -> PrivilegeLevel
Returns the requested privilege level.
pub fn set_rpl(&mut self, rpl: PrivilegeLevel)
pub fn set_rpl(&mut self, rpl: PrivilegeLevel)
Set the privilege level for this Segment selector.