XCr0

Struct XCr0 

pub struct XCr0;
Extended feature enable mask register

Implementations



impl XCr0

pub fn read() -> XCr0Flags

Read the current set of XCR0 flags.

pub fn read_raw() -> u64

Read the current raw XCR0 value.

pub unsafe fn write(flags: XCr0Flags)

Write XCR0 flags.

Preserves the value of reserved fields. Panics if invalid combinations of XCr0Flags are set.

Safety

This function is unsafe because it’s possible to enable features that are not supported by the architecture.

pub unsafe fn write_raw(value: u64)

Write raw XCR0 flags.

Does not preserve any values, including reserved fields.

Safety

This function is unsafe because it’s possible to enable features that are not supported by the architecture

pub unsafe fn update<F>(f: F)
where F: FnOnce(&mut XCr0Flags),

Update XCR0 flags.

Preserves the value of reserved fields. Panics if invalid combinations of XCr0Flags are set.

Safety

This function is unsafe because it’s possible to enable features that are not supported by the architecture.