Struct XCr0Flags
#[repr(transparent)]pub struct XCr0Flags(<XCr0Flags as PublicFlags>::Internal);Expand description
Tuple Fields
0: <XCr0Flags as PublicFlags>::InternalImplementations
impl XCr0Flags
impl XCr0Flags
pub const SSE: XCr0Flags
pub const SSE: XCr0Flags
Enables using MXCSR and the XMM registers
with XSAVE/XRSTOR.
Must be set if AVX is set.
pub const AVX: XCr0Flags
pub const AVX: XCr0Flags
Enables AVX instructions and using the upper halves of the AVX registers
with XSAVE/XRSTOR.
pub const BNDREG: XCr0Flags
pub const BNDREG: XCr0Flags
Enables MPX instructions and using the BND0-BND3 bound registers
with XSAVE/XRSTOR (Intel Only).
pub const BNDCSR: XCr0Flags
pub const BNDCSR: XCr0Flags
Enables MPX instructions and using the BNDCFGU and BNDSTATUS registers
with XSAVE/XRSTOR (Intel Only).
pub const OPMASK: XCr0Flags
pub const OPMASK: XCr0Flags
Enables AVX-512 instructions and using the K0-K7 mask registers
with XSAVE/XRSTOR (Intel Only).
pub const ZMM_HI256: XCr0Flags
pub const ZMM_HI256: XCr0Flags
Enables AVX-512 instructions and using the upper halves of the lower ZMM registers
with XSAVE/XRSTOR (Intel Only).
impl XCr0Flags
impl XCr0Flags
pub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u64) -> Option<XCr0Flags>
pub const fn from_bits(bits: u64) -> Option<XCr0Flags>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u64) -> XCr0Flags
pub const fn from_bits_truncate(bits: u64) -> XCr0Flags
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u64) -> XCr0Flags
pub const fn from_bits_retain(bits: u64) -> XCr0Flags
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<XCr0Flags>
pub fn from_name(name: &str) -> Option<XCr0Flags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: XCr0Flags) -> bool
pub const fn intersects(&self, other: XCr0Flags) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: XCr0Flags) -> bool
pub const fn contains(&self, other: XCr0Flags) -> bool
Whether all set bits in other are also set in self.
pub fn remove(&mut self, other: XCr0Flags)
pub fn remove(&mut self, other: XCr0Flags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: XCr0Flags)
pub fn toggle(&mut self, other: XCr0Flags)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: XCr0Flags, value: bool)
pub fn set(&mut self, other: XCr0Flags, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: XCr0Flags) -> XCr0Flags
pub const fn intersection(self, other: XCr0Flags) -> XCr0Flags
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: XCr0Flags) -> XCr0Flags
pub const fn union(self, other: XCr0Flags) -> XCr0Flags
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: XCr0Flags) -> XCr0Flags
pub const fn difference(self, other: XCr0Flags) -> XCr0Flags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: XCr0Flags) -> XCr0Flags
pub const fn symmetric_difference(self, other: XCr0Flags) -> XCr0Flags
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> XCr0Flags
pub const fn complement(self) -> XCr0Flags
The bitwise negation (!) of the bits in self, truncating the result.
impl XCr0Flags
impl XCr0Flags
pub const fn iter(&self) -> Iter<XCr0Flags> ⓘ
pub const fn iter(&self) -> Iter<XCr0Flags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<XCr0Flags> ⓘ
pub const fn iter_names(&self) -> IterNames<XCr0Flags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.