Struct PageFaultErrorCode
#[repr(transparent)]pub struct PageFaultErrorCode(<PageFaultErrorCode as PublicFlags>::Internal);Expand description
Describes an page fault error code.
This structure is defined by the following manual sections:
- AMD Volume 2: 8.4.2
- Intel Volume 3A: 4.7
Tuple Fields
0: <PageFaultErrorCode as PublicFlags>::InternalImplementations
impl PageFaultErrorCode
impl PageFaultErrorCode
pub const PROTECTION_VIOLATION: PageFaultErrorCode
pub const PROTECTION_VIOLATION: PageFaultErrorCode
If this flag is set, the page fault was caused by a page-protection violation, else the page fault was caused by a not-present page.
pub const CAUSED_BY_WRITE: PageFaultErrorCode
pub const CAUSED_BY_WRITE: PageFaultErrorCode
If this flag is set, the memory access that caused the page fault was a write. Else the access that caused the page fault is a memory read. This bit does not necessarily indicate the cause of the page fault was a read or write violation.
pub const USER_MODE: PageFaultErrorCode
pub const USER_MODE: PageFaultErrorCode
If this flag is set, an access in user mode (CPL=3) caused the page fault. Else an access in supervisor mode (CPL=0, 1, or 2) caused the page fault. This bit does not necessarily indicate the cause of the page fault was a privilege violation.
pub const MALFORMED_TABLE: PageFaultErrorCode
pub const MALFORMED_TABLE: PageFaultErrorCode
If this flag is set, the page fault is a result of the processor reading a 1 from a reserved field within a page-translation-table entry.
pub const INSTRUCTION_FETCH: PageFaultErrorCode
pub const INSTRUCTION_FETCH: PageFaultErrorCode
If this flag is set, it indicates that the access that caused the page fault was an instruction fetch.
pub const PROTECTION_KEY: PageFaultErrorCode
pub const PROTECTION_KEY: PageFaultErrorCode
If this flag is set, it indicates that the page fault was caused by a protection key.
pub const SHADOW_STACK: PageFaultErrorCode
pub const SHADOW_STACK: PageFaultErrorCode
If this flag is set, it indicates that the page fault was caused by a shadow stack access.
pub const HLAT: PageFaultErrorCode
pub const HLAT: PageFaultErrorCode
If this flag is set, it indicates that the page fault occurred during HLAT paging (Intel-only).
pub const SGX: PageFaultErrorCode
pub const SGX: PageFaultErrorCode
If this flag is set, it indicates that the page fault was caused by SGX access-control requirements (Intel-only).
pub const RMP: PageFaultErrorCode
pub const RMP: PageFaultErrorCode
If this flag is set, it indicates that the page fault is a result of the processor encountering an RMP violation (AMD-only).
impl PageFaultErrorCode
impl PageFaultErrorCode
pub const fn empty() -> PageFaultErrorCode
pub const fn empty() -> PageFaultErrorCode
Get a flags value with all bits unset.
pub const fn all() -> PageFaultErrorCode
pub const fn all() -> PageFaultErrorCode
Get a flags value with all known bits set.
pub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u64) -> Option<PageFaultErrorCode>
pub const fn from_bits(bits: u64) -> Option<PageFaultErrorCode>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u64) -> PageFaultErrorCode
pub const fn from_bits_truncate(bits: u64) -> PageFaultErrorCode
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u64) -> PageFaultErrorCode
pub const fn from_bits_retain(bits: u64) -> PageFaultErrorCode
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<PageFaultErrorCode>
pub fn from_name(name: &str) -> Option<PageFaultErrorCode>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: PageFaultErrorCode) -> bool
pub const fn intersects(&self, other: PageFaultErrorCode) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: PageFaultErrorCode) -> bool
pub const fn contains(&self, other: PageFaultErrorCode) -> bool
Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: PageFaultErrorCode)
pub fn insert(&mut self, other: PageFaultErrorCode)
The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: PageFaultErrorCode)
pub fn remove(&mut self, other: PageFaultErrorCode)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: PageFaultErrorCode)
pub fn toggle(&mut self, other: PageFaultErrorCode)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: PageFaultErrorCode, value: bool)
pub fn set(&mut self, other: PageFaultErrorCode, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: PageFaultErrorCode) -> PageFaultErrorCode
pub const fn intersection(self, other: PageFaultErrorCode) -> PageFaultErrorCode
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: PageFaultErrorCode) -> PageFaultErrorCode
pub const fn union(self, other: PageFaultErrorCode) -> PageFaultErrorCode
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: PageFaultErrorCode) -> PageFaultErrorCode
pub const fn difference(self, other: PageFaultErrorCode) -> PageFaultErrorCode
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(
self,
other: PageFaultErrorCode,
) -> PageFaultErrorCode
pub const fn symmetric_difference( self, other: PageFaultErrorCode, ) -> PageFaultErrorCode
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> PageFaultErrorCode
pub const fn complement(self) -> PageFaultErrorCode
The bitwise negation (!) of the bits in self, truncating the result.
impl PageFaultErrorCode
impl PageFaultErrorCode
pub const fn iter(&self) -> Iter<PageFaultErrorCode> ⓘ
pub const fn iter(&self) -> Iter<PageFaultErrorCode> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<PageFaultErrorCode> ⓘ
pub const fn iter_names(&self) -> IterNames<PageFaultErrorCode> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.