Struct SelectorErrorCode
#[repr(transparent)]pub struct SelectorErrorCode {
flags: u64,
}Expand description
Describes an error code referencing a segment selector.
Fields
flags: u64Implementations
impl SelectorErrorCode
impl SelectorErrorCode
pub const fn new(value: u64) -> Option<SelectorErrorCode>
pub const fn new(value: u64) -> Option<SelectorErrorCode>
Create a SelectorErrorCode. Returns None is any of the reserved bits (16-64) are set.
pub const fn new_truncate(value: u64) -> SelectorErrorCode
pub const fn new_truncate(value: u64) -> SelectorErrorCode
Create a new SelectorErrorCode dropping any reserved bits (16-64).
pub fn external(&self) -> bool
pub fn external(&self) -> bool
If true, indicates that the exception occurred during delivery of an event external to the program, such as an interrupt or an earlier exception.
pub fn descriptor_table(&self) -> DescriptorTable
pub fn descriptor_table(&self) -> DescriptorTable
The descriptor table this error code refers to.