Enum FlagUpdateError
pub enum FlagUpdateError {
PageNotMapped,
ParentEntryHugePage,
}Expand description
An error indicating that an update_flags call failed.
Variants
PageNotMapped
The given page is not mapped to a physical frame.
ParentEntryHugePage
An upper level page table entry has the HUGE_PAGE flag set, which means that the
given page is part of a huge page and can’t be freed individually.