Enum InvalidPageTable
pub enum InvalidPageTable {
NotRecursive,
NotActive,
}Expand description
The given page table was not suitable to create a RecursivePageTable.
Variants
NotRecursive
The given page table was not at an recursive address.
The page table address must be of the form 0o_xxx_xxx_xxx_xxx_0000 where xxx
is the recursive entry.
NotActive
The given page table was not active on the CPU.
The recursive page table design requires that the given level 4 table is active on the CPU because otherwise it’s not possible to access the other page tables through recursive memory addresses.