Enum MapToError
pub enum MapToError<S>where
S: PageSize,{
FrameAllocationFailed,
ParentEntryHugePage,
PageAlreadyMapped(PhysFrame<S>),
}Expand description
This error is returned from map_to and similar methods.
Variants
FrameAllocationFailed
An additional frame was needed for the mapping process, but the frame allocator
returned None.
ParentEntryHugePage
An upper level page table entry has the HUGE_PAGE flag set, which means that the
given page is part of an already mapped huge page.
PageAlreadyMapped(PhysFrame<S>)
The given page is already mapped to a physical frame.