Enum TranslateError
pub enum TranslateError {
PageNotMapped,
ParentEntryHugePage,
InvalidFrameAddress(PhysAddr),
}Expand description
An error indicating that an translate call failed.
Variants
PageNotMapped
The given page is not mapped to a physical frame.
ParentEntryHugePage
An upper level page table entry has the HUGE_PAGE flag set, which means that the
given page is part of a huge page and can’t be freed individually.
InvalidFrameAddress(PhysAddr)
The page table entry for the given page points to an invalid physical address.