MapperFlush

Struct MapperFlush 

pub struct MapperFlush<S>(Page<S>)
where
    S: PageSize;
This type represents a page whose mapping has changed in the page table.

The old mapping might be still cached in the translation lookaside buffer (TLB), so it needs to be flushed from the TLB before it’s accessed. This type is returned from a function that changed the mapping of a page to ensure that the TLB flush is not forgotten.

Tuple Fields

0: Page<S>

Implementations



impl<S> MapperFlush<S>
where S: PageSize,

pub fn new(page: Page<S>) -> MapperFlush<S>

Create a new flush promise

Note that this method is intended for implementing the Mapper trait and no other uses are expected.

pub fn flush(self)

Flush the page from the TLB to ensure that the newest mapping is used.

pub fn ignore(self)

Don’t flush the TLB and silence the “must be used” warning.

pub fn page(&self) -> Page<S>

Returns the page to be flushed.