MapperFlushAll

Struct MapperFlushAll 

pub struct MapperFlushAll(());
This type represents a change of a page table requiring a complete TLB flush

The old mapping might be still cached in the translation lookaside buffer (TLB), so it needs to be flushed from the TLB before it’s accessed. This type is returned from a function that made the change to ensure that the TLB flush is not forgotten.

Tuple Fields

0: ()

Implementations



impl MapperFlushAll

pub fn new() -> MapperFlushAll

Create a new flush promise

Note that this method is intended for implementing the Mapper trait and no other uses are expected.

pub fn flush_all(self)

Flush all pages from the TLB to ensure that the newest mapping is used.

pub fn ignore(self)

Don’t flush the TLB and silence the “must be used” warning.