Struct PageTable
#[repr(C, align(4096))]pub struct PageTable {
entries: [PageTableEntry; 512],
}Expand description
Represents a page table.
Always page-sized.
This struct implements the Index and IndexMut traits, so the entries can be accessed
through index operations. For example, page_table[15] returns the 16th page table entry.
Note that while this type implements Clone, the users must be careful not to introduce
mutable aliasing by using the cloned page tables.
Fields
entries: [PageTableEntry; 512]Implementations
impl PageTable
impl PageTable
pub fn zero(&mut self)
pub fn zero(&mut self)
Clears all entries.
pub fn iter(&self) -> impl Iterator<Item = &PageTableEntry>
pub fn iter(&self) -> impl Iterator<Item = &PageTableEntry>
Returns an iterator over the entries of the page table.
pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut PageTableEntry>
pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut PageTableEntry>
Returns an iterator that allows modifying the entries of the page table.