PageTableEntry

Struct PageTableEntry 

#[repr(transparent)]
pub struct PageTableEntry { entry: u64, }
A 64-bit page table entry.

Fields

entry: u64

Implementations



impl PageTableEntry

pub const fn new() -> PageTableEntry

Creates an unused page table entry.

pub const fn is_unused(&self) -> bool

Returns whether this entry is zero.

pub fn set_unused(&mut self)

Sets this entry to zero.

pub const fn flags(&self) -> PageTableFlags

Returns the flags of this entry.

pub fn addr(&self) -> PhysAddr

Returns the physical address mapped by this entry, might be zero.

pub fn frame(&self) -> Result<PhysFrame, FrameError>

Returns the physical frame mapped by this entry.

Returns the following errors:

  • FrameError::FrameNotPresent if the entry doesn’t have the PRESENT flag set.
  • FrameError::HugeFrame if the entry has the HUGE_PAGE flag set (for huge pages the addr function must be used)

pub fn set_addr(&mut self, addr: PhysAddr, flags: PageTableFlags)

Map the entry to the specified physical address with the specified flags.

pub fn set_frame(&mut self, frame: PhysFrame, flags: PageTableFlags)

Map the entry to the specified physical frame with the specified flags.

pub fn set_flags(&mut self, flags: PageTableFlags)

Sets the flags of this entry.