InvalidIoMap

Enum InvalidIoMap 

pub enum InvalidIoMap {
    IoMapBeforeTss,
    TooFarFromTss {
        distance: usize,
    },
    InvalidTerminatingByte {
        byte: u8,
    },
    TooLong {
        len: usize,
    },
    InvalidBase {
        expected: u16,
        got: u16,
    },
}
The given IO permissions bitmap is invalid.

Variants



IoMapBeforeTss

The IO permissions bitmap is before the TSS. It must be located after the TSS.



TooFarFromTss

The IO permissions bitmap is too far from the TSS. It must be within 0xdfff bytes of the start of the TSS. Note that if the IO permissions bitmap is located before the TSS, then IoMapBeforeTss will be returned instead.

Fields

distance: usize

The distance of the IO permissions bitmap from the beginning of the TSS.



InvalidTerminatingByte

The final byte of the IO permissions bitmap was not 0xff

Fields

byte: u8

The byte found at the end of the IO permissions bitmap.



TooLong

The IO permissions bitmap exceeds the maximum length (8193).

Fields

len: usize

The length of the IO permissions bitmap.



InvalidBase

The iomap_base in the TaskStateSegment struct was not what was expected.

Fields

expected: u16

The expected iomap_base to be set in the TaskStateSegment struct.

got: u16

The actual iomap_base set in the TaskStateSegment struct.