VgaWriter

Struct VgaWriter 

pub struct VgaWriter { /* private fields */ }

Implementations

Source

impl VgaWriter

pub const fn new() -> Self

Creates a new instance.

pub fn set_color(&mut self, fg: Color, bg: Color)

Sets color.

pub fn set_rgb_color(&mut self, fg: RgbColor, bg: RgbColor)

Sets rgb color.

pub fn text_colors(&self) -> (RgbColor, RgbColor)

Performs the text colors operation.

pub fn width(&self) -> usize

Performs the width operation.

pub fn height(&self) -> usize

Performs the height operation.

pub fn cols(&self) -> usize

Performs the cols operation.

pub fn rows(&self) -> usize

Performs the rows operation.

pub fn glyph_size(&self) -> (usize, usize)

Performs the glyph size operation.

pub fn set_cursor_cell(&mut self, col: usize, row: usize)

Sets cursor cell.

pub fn enabled(&self) -> bool

Performs the enabled operation.

pub fn framebuffer_info(&self) -> FramebufferInfo

Performs the framebuffer info operation.

pub fn set_clip_rect(&mut self, x: usize, y: usize, width: usize, height: usize)

Sets clip rect.

pub fn reset_clip_rect(&mut self)

Performs the reset clip rect operation.

pub fn enable_double_buffer(&mut self) -> bool

Enables double buffer.

pub fn disable_double_buffer(&mut self, present: bool)

Disables double buffer.

pub fn present(&mut self)

Performs the present operation.

pub fn update_mouse_cursor(&mut self, x: i32, y: i32)

Updates mouse cursor.

pub fn hide_mouse_cursor(&mut self)

Performs the hide mouse cursor operation.

pub fn pixel_to_sb_pos(&self, px: usize, py: usize) -> Option<(usize, usize)>

Performs the pixel to sb pos operation.

pub fn start_selection(&mut self, px: usize, py: usize)

Starts selection.

pub fn update_selection(&mut self, px: usize, py: usize)

Updates selection.

pub fn end_selection(&mut self)

Performs the end selection operation.

pub fn clear_selection(&mut self)

Performs the clear selection operation.

pub fn clear_with(&mut self, color: RgbColor)

Performs the clear with operation.

pub fn clear(&mut self)

Performs the clear operation.

pub fn draw_pixel(&mut self, x: usize, y: usize, color: RgbColor)

Performs the draw pixel operation.

pub fn draw_pixel_alpha( &mut self, x: usize, y: usize, color: RgbColor, alpha: u8, )

Performs the draw pixel alpha operation.

pub fn draw_line( &mut self, x0: isize, y0: isize, x1: isize, y1: isize, color: RgbColor, )

Performs the draw line operation.

pub fn draw_rect( &mut self, x: usize, y: usize, width: usize, height: usize, color: RgbColor, )

Performs the draw rect operation.

pub fn fill_rect( &mut self, x: usize, y: usize, width: usize, height: usize, color: RgbColor, )

Performs the fill rect operation.

pub fn fill_rect_alpha( &mut self, x: usize, y: usize, width: usize, height: usize, color: RgbColor, alpha: u8, )

Performs the fill rect alpha operation.

pub fn blit_rgb( &mut self, dst_x: usize, dst_y: usize, src_width: usize, src_height: usize, pixels: &[RgbColor], ) -> bool

Performs the blit rgb operation.

pub fn blit_rgb24( &mut self, dst_x: usize, dst_y: usize, src_width: usize, src_height: usize, bytes: &[u8], ) -> bool

Performs the blit rgb24 operation.

pub fn blit_rgba( &mut self, dst_x: usize, dst_y: usize, src_width: usize, src_height: usize, bytes: &[u8], global_alpha: u8, ) -> bool

Performs the blit rgba operation.

pub fn blit_sprite_rgba( &mut self, dst_x: usize, dst_y: usize, sprite: SpriteRgba<'_>, global_alpha: u8, ) -> bool

Performs the blit sprite rgba operation.

pub fn draw_text_at( &mut self, pixel_x: usize, pixel_y: usize, text: &str, fg: RgbColor, bg: RgbColor, )

Performs the draw text at operation.

pub fn measure_text( &self, text: &str, max_width: Option<usize>, wrap: bool, ) -> TextMetrics

Performs the measure text operation.

pub fn draw_text( &mut self, pixel_x: usize, pixel_y: usize, text: &str, opts: TextOptions, ) -> TextMetrics

Performs the draw text operation.

pub fn draw_strata_stack( &mut self, origin_x: usize, origin_y: usize, layer_w: usize, layer_h: usize, )

Performs the draw strata stack operation.

pub fn scroll_view_up(&mut self, lines: usize)

Scroll the view up (backward in history) by lines lines.

pub fn scroll_view_down(&mut self, lines: usize)

Scroll the view down (forward, toward live) by lines lines.

pub fn scroll_to_live(&mut self)

Immediately return to the live (bottom) view.

pub fn scrollbar_click(&mut self, px_x: usize, px_y: usize)

Handle a click at pixel (px_x, px_y) — if it falls in the scrollbar, jump the view to the corresponding scroll position.

pub fn scrollbar_drag_to(&mut self, px_y: usize)

Drag the scrollbar thumb to vertical pixel px_y.

Unlike scrollbar_click, this only depends on Y and is intended for click-and-drag interactions where the pointer may slightly leave the scrollbar strip horizontally.

pub fn scrollbar_hit_test(&self, px_x: usize, px_y: usize) -> bool

Returns true if the pixel coordinates fall within the scrollbar strip.