pub fn push_completion(
ring_id: u64,
user_data: u64,
result: i32,
flags: u32,
) -> boolExpand description
Push a completion event to the ring identified by ring_id.
Returns true on success, false if the ring was not found or destroyed.