pub unsafe fn build_kernel_args_from_dtb(dtb_ptr: u64) -> KernelArgsExpand description
Parse the Flattened Device Tree and build a KernelArgs structure.
Safety
dtb_ptr must point to a valid flattened device tree in memory.
pub unsafe fn build_kernel_args_from_dtb(dtb_ptr: u64) -> KernelArgsParse the Flattened Device Tree and build a KernelArgs structure.
dtb_ptr must point to a valid flattened device tree in memory.