fn extract_block() -> [u8; 8]Expand description
Extract 8 bytes from the pool by folding all words together.
This is not a cryptographic hash : it’s a feed‑forward compression that provides avalanche. If the pool has been seeded from RDRAND and stirred by interrupt noise, the output is cryptographically acceptable.