pub fn get_device() -> Option<&'static VirtioBlockDevice>Expand description
Get the global VirtIO block device
Returns a 'static reference that is valid for the entire kernel lifetime.
The device is initialised once during boot and never removed.
pub fn get_device() -> Option<&'static VirtioBlockDevice>Get the global VirtIO block device
Returns a 'static reference that is valid for the entire kernel lifetime.
The device is initialised once during boot and never removed.