pub fn wait_for_reply(task_id: TaskId) -> IpcMessageExpand description
Block the current task waiting for a reply message.
Returns an EPIPE error reply if the slot was removed while waiting (e.g. the server died and cleanup ran).
pub fn wait_for_reply(task_id: TaskId) -> IpcMessageBlock the current task waiting for a reply message.
Returns an EPIPE error reply if the slot was removed while waiting (e.g. the server died and cleanup ran).