pub fn resolve_handle(phys: PhysAddr) -> BlockHandleExpand description
Resolves a physical address to the current block handle. If the address is not currently owned, a new handle is reconstructed from the metadata.
pub fn resolve_handle(phys: PhysAddr) -> BlockHandleResolves a physical address to the current block handle. If the address is not currently owned, a new handle is reconstructed from the metadata.