pub fn alloc(
_token: &IrqDisabledToken,
order: u8,
) -> Result<PhysFrame, AllocError>Expand description
Allocate frames with per-CPU caching on order-0 requests.
_token is a compile-time proof that interrupts are disabled on the calling CPU,
preventing re-entrant allocation through an interrupt handler on the same lock.