pub enum RemoveRefResult {
Freed(PhysBlock<Released>),
NowExclusive {
remaining_cap: CapId,
},
StillPinned {
transient_refs: u32,
},
StillShared {
refcount: u32,
},
}Expand description
Result of removing one capability reference from a block.
Variants
Freed(PhysBlock<Released>)
The block has no remaining owners and can return to the buddy.
NowExclusive
Exactly one owner remains.
StillPinned
No capability remains, but transient pins still keep the block alive.
Multiple owners still reference the block.