fn capture_attr(size: usize, caller: &'static Location<'static>) -> VmallocAttrExpand description
Capture attribution for the calling task, without holding VMALLOC.
Must be called before acquiring the VMALLOC lock to maintain the VMALLOC → SILO_MANAGER lock ordering and to avoid deadlocking if vmalloc is called from within silo or scheduler code.
Uses current_task_clone_try() (non-blocking) so that vmalloc called
from within a scheduler path cannot deadlock on the per-CPU scheduler lock.