Zone

Struct Zone 

pub struct Zone {
    pub zone_type: ZoneType,
    pub base: PhysAddr,
    pub page_count: usize,
    pub span_pages: usize,
    pub allocated: usize,
    pub free_lists: [u64; 12],
    pub buddy_bitmaps: [BuddyBitmap; 12],
    pub alloc_bitmap: BuddyBitmap,
}
Memory zone with buddy allocator free lists

Fields

zone_type: ZoneType

Zone type

base: PhysAddr

Base physical address of this zone

page_count: usize

Total number of managed pages in this zone.

span_pages: usize

Total address span covered by this zone metadata, in pages.

Unlike page_count, this includes holes and is used to size bitmaps.

allocated: usize

Number of allocated pages

free_lists: [u64; 12]

Free lists for each order (0-11), intrusive list head as physical addr. 0 means empty.

buddy_bitmaps: [BuddyBitmap; 12]

Per-order buddy pair bitmaps (Linux-style parity map).

alloc_bitmap: BuddyBitmap

Optional debug bitmap: 1 bit per page = allocated.

Implementations

Source

impl Zone

pub const fn new(zone_type: ZoneType) -> Self

Create a new empty zone

pub fn contains_address(&self, addr: PhysAddr) -> bool

Check if an address is within this zone

pub fn available_pages(&self) -> usize

Get number of available (free) pages