pub fn raise_deferred_work(work: DeferredWork)Expand description
Raise deferred work items for the current CPU.
Called from the timer interrupt handler to signal that heavy processing should happen at the next safe point. This is lock-free and O(1).
Safety
Safe to call from any context (including hardirq with interrupts disabled).