pub fn kill_task(id: TaskId) -> boolExpand description
Kill a task by ID (best-effort).
- Ready / blocked tasks are removed and marked Dead immediately.
- If the task is the current task on this CPU, a context switch is performed immediately.
- If the task is the current task on another CPU, an IPI triggers preemption on that CPU; the task will not be re-queued because its state is Dead.
Returns true if the task was found and killed.