suspend_task

Function suspend_task 

pub fn suspend_task(id: TaskId) -> bool
Suspend a task by ID (best-effort).

Moves the task to the blocked map and marks it Blocked.

  • If the task is the current task on this CPU, a context switch is performed immediately.
  • If the task is the current task on another CPU, an IPI is sent to trigger preemption on that CPU. The task will not be re-queued at the next tick because its state is Blocked.