wake_task

Function wake_task 

pub fn wake_task(id: TaskId) -> bool
Wake a blocked task by its ID.

Moves the task from blocked_tasks to the ready queue and sets its state to Ready. Returns true if the task was found and woken.

Lost-wakeup prevention

If the task is not yet in blocked_tasks (it is still transitioning from Ready -> Blocked inside block_current_task()), this function sets the task’s wake_pending flag so that block_current_task() will see the pending wakeup and return immediately without actually blocking.