Signal

Enum Signal 

#[repr(u32)]
pub enum Signal {
Show 30 variants SIGHUP = 1, SIGINT = 2, SIGQUIT = 3, SIGILL = 4, SIGTRAP = 5, SIGABRT = 6, SIGBUS = 7, SIGFPE = 8, SIGKILL = 9, SIGUSR1 = 10, SIGSEGV = 11, SIGUSR2 = 12, SIGPIPE = 13, SIGALRM = 14, SIGTERM = 15, SIGCHLD = 17, SIGCONT = 18, SIGSTOP = 19, SIGTSTP = 20, SIGTTIN = 21, SIGTTOU = 22, SIGURG = 23, SIGXCPU = 24, SIGXFSZ = 25, SIGVTALRM = 26, SIGPROF = 27, SIGWINCH = 28, SIGIO = 29, SIGPWR = 30, SIGSYS = 31,
}
Signal numbers (POSIX-compatible).

Standard POSIX signal numbers for compatibility with userspace libc.

Variants



SIGHUP = 1

Hangup detected on controlling terminal



SIGINT = 2

Interrupt from keyboard (Ctrl+C)



SIGQUIT = 3

Quit from keyboard (Ctrl+)



SIGILL = 4

Illegal instruction



SIGTRAP = 5

Trace/breakpoint trap



SIGABRT = 6

Abort signal



SIGBUS = 7

Bus error (bad memory access)



SIGFPE = 8

Floating-point exception



SIGKILL = 9

Kill signal (cannot be caught or ignored)



SIGUSR1 = 10

User-defined signal 1



SIGSEGV = 11

Segmentation fault



SIGUSR2 = 12

User-defined signal 2



SIGPIPE = 13

Broken pipe



SIGALRM = 14

Timer signal



SIGTERM = 15

Termination signal



SIGCHLD = 17

Child stopped or terminated



SIGCONT = 18

Continue if stopped



SIGSTOP = 19

Stop process (cannot be caught or ignored)



SIGTSTP = 20

Stop typed at terminal



SIGTTIN = 21

Background read attempt



SIGTTOU = 22

Background write attempt



SIGURG = 23

Urgent data on socket



SIGXCPU = 24

CPU time limit exceeded



SIGXFSZ = 25

File size limit exceeded



SIGVTALRM = 26

Virtual timer expired



SIGPROF = 27

Profiling timer expired



SIGWINCH = 28

Window size changed



SIGIO = 29

I/O possible on socket



SIGPWR = 30

Power failure



SIGSYS = 31

Bad system call

Implementations

Source

impl Signal

pub fn from_u32(num: u32) -> Option<Self>

Convert a signal number to a Signal enum.

pub fn as_u32(self) -> u32

Convert Signal to its numeric value.

pub fn is_uncatchable(self) -> bool

Check if this signal cannot be caught or blocked.

pub fn bit(self) -> u64

Get the bit position for this signal in a signal mask.

Source

impl Signal

pub fn default_action(self) -> DefaultAction

Performs the default action operation.