pub struct SpinLock<T> { /* private fields */ }Expand description
A simple spinlock
Implementations
Sourceimpl<T> SpinLock<T>
impl<T> SpinLock<T>
Sourcepub fn lock(&self) -> SpinLockGuard<'_, T>
pub fn lock(&self) -> SpinLockGuard<'_, T>
Acquire the lock, spinning until it’s available
Sourcepub fn try_lock(&self) -> Option<SpinLockGuard<'_, T>>
pub fn try_lock(&self) -> Option<SpinLockGuard<'_, T>>
Try to acquire the lock without spinning.
Sourcepub fn try_lock_no_irqsave(&self) -> Option<SpinLockGuard<'_, T>>
pub fn try_lock_no_irqsave(&self) -> Option<SpinLockGuard<'_, T>>
Try to acquire the lock without touching interrupt flags.
Returns None if IRQs are currently enabled (i.e. no IrqDisabledToken
can be constructed) or if the lock is already held.
Caller must ensure IRQs remain disabled for the lifetime of the guard.