pub fn sys_mremap(
old_addr: u64,
old_size: u64,
new_size: u64,
flags: u64,
) -> Result<u64, SyscallError>Expand description
SYS_MREMAP (103): resize an existing mapping.
Current support:
- Shrink in place.
- Grow in place when the following range is free.
- If
MREMAP_MAYMOVEis set and growth in place fails, relocate only when the source mapping is still fully lazy (no present pages yet).