fn sector_write<D: BlockDevice>(
dev: &D,
offset: u64,
data: &[u8],
) -> Result<usize, BlockError>Expand description
Write data bytes to the block device starting at byte offset.
For partial-sector writes the affected sector is first read, patched in memory, then written back (read-modify-write).