IpcScheme

Struct IpcScheme 

pub struct IpcScheme {
    port_id: PortId,
    open_file_flags: SpinLock<BTreeMap<u64, FileFlags>>,
}
IPC-based scheme: forwards operations to a userspace server via IPC.

Fields

port_id: PortIdopen_file_flags: SpinLock<BTreeMap<u64, FileFlags>>

Implementations

Source

impl IpcScheme

pub fn new(port_id: PortId) -> Self

Creates a new instance.

fn remember_open_flags(&self, file_id: u64, flags: FileFlags)

fn take_open_flags(&self, file_id: u64)

fn open_flags_for(&self, file_id: u64) -> FileFlags

fn build_open_msg( path: &str, flags: OpenFlags, ) -> Result<IpcMessage, SyscallError>

Build an IPC message for open operation.

fn build_read_msg(file_id: u64, offset: u64, count: u32) -> IpcMessage

Build an IPC message for read operation.

fn build_write_msg( file_id: u64, offset: u64, data: &[u8], ) -> (IpcMessage, usize)

Build an IPC message for write operation.

Returns the message and the number of bytes actually packed.

fn build_close_msg(file_id: u64) -> IpcMessage

Build an IPC message for close operation.

fn build_readdir_msg(file_id: u64, cursor: u16) -> IpcMessage

Performs the build readdir msg operation.

fn parse_status(reply: &IpcMessage) -> Result<(), SyscallError>

Parses status.

Source

impl IpcScheme

fn call(&self, msg: IpcMessage) -> Result<IpcMessage, SyscallError>

Perform a synchronous IPC call: send msg to the server port and block the current task until the server calls ipc_reply. This mirrors sys_ipc_call exactly so that sys_ipc_reply can correctly route the reply back to us via reply::deliver_reply.

Source

impl IpcScheme

fn handle_create_op( &self, opcode: u32, path: &str, mode: u32, ) -> Result<OpenResult, SyscallError>

Handles create op.