Enum PrivilegeLevel
#[repr(u8)]pub enum PrivilegeLevel {
Ring0 = 0,
Ring1 = 1,
Ring2 = 2,
Ring3 = 3,
}Expand description
Represents a protection ring level.
Variants
Ring0 = 0
Privilege-level 0 (most privilege): This level is used by critical system-software components that require direct access to, and control over, all processor and system resources. This can include BIOS, memory-management functions, and interrupt handlers.
Ring1 = 1
Privilege-level 1 (moderate privilege): This level is used by less-critical system- software services that can access and control a limited scope of processor and system resources. Software running at these privilege levels might include some device drivers and library routines. The actual privileges of this level are defined by the operating system.
Ring2 = 2
Privilege-level 2 (moderate privilege): Like level 1, this level is used by less-critical system-software services that can access and control a limited scope of processor and system resources. The actual privileges of this level are defined by the operating system.
Ring3 = 3
Privilege-level 3 (least privilege): This level is used by application software. Software running at privilege-level 3 is normally prevented from directly accessing most processor and system resources. Instead, applications request access to the protected processor and system resources by calling more-privileged service routines to perform the accesses.
Implementations
impl PrivilegeLevel
impl PrivilegeLevel
pub const fn from_u16(value: u16) -> PrivilegeLevel
pub const fn from_u16(value: u16) -> PrivilegeLevel
Creates a PrivilegeLevel from a numeric value. The value must be in the range 0..4.
This function panics if the passed value is >3.