Struct Cr0
pub struct Cr0;Expand description
Various control flags modifying the basic operation of the CPU.
Implementations
impl Cr0
impl Cr0
pub unsafe fn write(flags: Cr0Flags)
pub unsafe fn write(flags: Cr0Flags)
Write CR0 flags.
Preserves the value of reserved fields.
Safety
This function is unsafe because it’s possible to violate memory safety through it, e.g. by disabling paging.