Struct Dr7Flags
#[repr(transparent)]pub struct Dr7Flags(<Dr7Flags as PublicFlags>::Internal);Expand description
Debug control flags of the Dr7 register.
Tuple Fields
0: <Dr7Flags as PublicFlags>::InternalImplementations
impl Dr7Flags
impl Dr7Flags
pub const LOCAL_BREAKPOINT_0_ENABLE: Dr7Flags
pub const LOCAL_BREAKPOINT_0_ENABLE: Dr7Flags
Breakpoint 0 is enabled for the current task.
pub const LOCAL_BREAKPOINT_1_ENABLE: Dr7Flags
pub const LOCAL_BREAKPOINT_1_ENABLE: Dr7Flags
Breakpoint 1 is enabled for the current task.
pub const LOCAL_BREAKPOINT_2_ENABLE: Dr7Flags
pub const LOCAL_BREAKPOINT_2_ENABLE: Dr7Flags
Breakpoint 2 is enabled for the current task.
pub const LOCAL_BREAKPOINT_3_ENABLE: Dr7Flags
pub const LOCAL_BREAKPOINT_3_ENABLE: Dr7Flags
Breakpoint 3 is enabled for the current task.
pub const GLOBAL_BREAKPOINT_0_ENABLE: Dr7Flags
pub const GLOBAL_BREAKPOINT_0_ENABLE: Dr7Flags
Breakpoint 0 is enabled for all tasks.
pub const GLOBAL_BREAKPOINT_1_ENABLE: Dr7Flags
pub const GLOBAL_BREAKPOINT_1_ENABLE: Dr7Flags
Breakpoint 1 is enabled for all tasks.
pub const GLOBAL_BREAKPOINT_2_ENABLE: Dr7Flags
pub const GLOBAL_BREAKPOINT_2_ENABLE: Dr7Flags
Breakpoint 2 is enabled for all tasks.
pub const GLOBAL_BREAKPOINT_3_ENABLE: Dr7Flags
pub const GLOBAL_BREAKPOINT_3_ENABLE: Dr7Flags
Breakpoint 3 is enabled for all tasks.
pub const LOCAL_EXACT_BREAKPOINT_ENABLE: Dr7Flags
pub const LOCAL_EXACT_BREAKPOINT_ENABLE: Dr7Flags
Enable detection of exact instruction causing a data breakpoint condition for the current task.
This is not supported by x86_64 processors, but is recommended to be enabled for backward and forward compatibility.
pub const GLOBAL_EXACT_BREAKPOINT_ENABLE: Dr7Flags
pub const GLOBAL_EXACT_BREAKPOINT_ENABLE: Dr7Flags
Enable detection of exact instruction causing a data breakpoint condition for all tasks.
This is not supported by x86_64 processors, but is recommended to be enabled for backward and forward compatibility.
pub const RESTRICTED_TRANSACTIONAL_MEMORY: Dr7Flags
pub const RESTRICTED_TRANSACTIONAL_MEMORY: Dr7Flags
Enables advanced debugging of RTM transactional regions.
The RTM flag in the IA32_DEBUGCTL [Msr] must also be set.
pub const GENERAL_DETECT_ENABLE: Dr7Flags
pub const GENERAL_DETECT_ENABLE: Dr7Flags
Enables debug register protection.
This will cause a debug exception before any access to a debug register.
impl Dr7Flags
impl Dr7Flags
pub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u64) -> Option<Dr7Flags>
pub const fn from_bits(bits: u64) -> Option<Dr7Flags>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u64) -> Dr7Flags
pub const fn from_bits_truncate(bits: u64) -> Dr7Flags
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u64) -> Dr7Flags
pub const fn from_bits_retain(bits: u64) -> Dr7Flags
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<Dr7Flags>
pub fn from_name(name: &str) -> Option<Dr7Flags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: Dr7Flags) -> bool
pub const fn intersects(&self, other: Dr7Flags) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: Dr7Flags) -> bool
pub const fn contains(&self, other: Dr7Flags) -> bool
Whether all set bits in other are also set in self.
pub fn remove(&mut self, other: Dr7Flags)
pub fn remove(&mut self, other: Dr7Flags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: Dr7Flags)
pub fn toggle(&mut self, other: Dr7Flags)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: Dr7Flags, value: bool)
pub fn set(&mut self, other: Dr7Flags, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: Dr7Flags) -> Dr7Flags
pub const fn intersection(self, other: Dr7Flags) -> Dr7Flags
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: Dr7Flags) -> Dr7Flags
pub const fn union(self, other: Dr7Flags) -> Dr7Flags
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: Dr7Flags) -> Dr7Flags
pub const fn difference(self, other: Dr7Flags) -> Dr7Flags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: Dr7Flags) -> Dr7Flags
pub const fn symmetric_difference(self, other: Dr7Flags) -> Dr7Flags
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> Dr7Flags
pub const fn complement(self) -> Dr7Flags
The bitwise negation (!) of the bits in self, truncating the result.
impl Dr7Flags
impl Dr7Flags
pub const fn iter(&self) -> Iter<Dr7Flags> ⓘ
pub const fn iter(&self) -> Iter<Dr7Flags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<Dr7Flags> ⓘ
pub const fn iter_names(&self) -> IterNames<Dr7Flags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
impl Dr7Flags
impl Dr7Flags
pub fn local_breakpoint_enable(n: DebugAddressRegisterNumber) -> Dr7Flags
pub fn local_breakpoint_enable(n: DebugAddressRegisterNumber) -> Dr7Flags
Returns the local breakpoint enable flag of the provided debug address register.
pub fn global_breakpoint_enable(n: DebugAddressRegisterNumber) -> Dr7Flags
pub fn global_breakpoint_enable(n: DebugAddressRegisterNumber) -> Dr7Flags
Returns the global breakpoint enable flag of the provided debug address register.