Struct Dr7Value
#[repr(transparent)]pub struct Dr7Value {
bits: u64,
}Expand description
Fields
bits: u64Implementations
impl Dr7Value
impl Dr7Value
pub const fn from_bits(bits: u64) -> Option<Dr7Value>
pub const fn from_bits(bits: u64) -> Option<Dr7Value>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a field.
pub const fn from_bits_truncate(bits: u64) -> Dr7Value
pub const fn from_bits_truncate(bits: u64) -> Dr7Value
Convert from underlying bit representation, dropping any bits that do not correspond to fields.
pub const unsafe fn from_bits_unchecked(bits: u64) -> Dr7Value
pub const unsafe fn from_bits_unchecked(bits: u64) -> Dr7Value
pub fn insert_flags(&mut self, flags: Dr7Flags)
pub fn insert_flags(&mut self, flags: Dr7Flags)
Inserts the specified Dr7Flags in-place.
pub fn remove_flags(&mut self, flags: Dr7Flags)
pub fn remove_flags(&mut self, flags: Dr7Flags)
Removes the specified Dr7Flags in-place.
pub fn toggle_flags(&mut self, flags: Dr7Flags)
pub fn toggle_flags(&mut self, flags: Dr7Flags)
Toggles the specified Dr7Flags in-place.
pub fn set_flags(&mut self, flags: Dr7Flags, value: bool)
pub fn set_flags(&mut self, flags: Dr7Flags, value: bool)
Inserts or removes the specified Dr7Flags depending on the passed value.
pub fn condition(&self, n: DebugAddressRegisterNumber) -> BreakpointCondition
pub fn condition(&self, n: DebugAddressRegisterNumber) -> BreakpointCondition
Returns the condition field of a debug address register.
pub fn set_condition(
&mut self,
n: DebugAddressRegisterNumber,
condition: BreakpointCondition,
)
pub fn set_condition( &mut self, n: DebugAddressRegisterNumber, condition: BreakpointCondition, )
Sets the condition field of a debug address register.
pub fn size(&self, n: DebugAddressRegisterNumber) -> BreakpointSize
pub fn size(&self, n: DebugAddressRegisterNumber) -> BreakpointSize
Returns the size field of a debug address register.
pub fn set_size(&mut self, n: DebugAddressRegisterNumber, size: BreakpointSize)
pub fn set_size(&mut self, n: DebugAddressRegisterNumber, size: BreakpointSize)
Sets the size field of a debug address register.