Struct Page
#[repr(C)]pub struct Page<S = Size4KiB>where
S: PageSize,{
start_address: VirtAddr,
size: PhantomData<S>,
}Expand description
A virtual memory page.
Fields
start_address: VirtAddrsize: PhantomData<S>Implementations
impl<S> Page<S>where
S: PageSize,
impl<S> Page<S>where
S: PageSize,
pub const fn from_start_address(
address: VirtAddr,
) -> Result<Page<S>, AddressNotAligned>
pub const fn from_start_address( address: VirtAddr, ) -> Result<Page<S>, AddressNotAligned>
Returns the page that starts at the given virtual address.
Returns an error if the address is not correctly aligned (i.e. is not a valid page start).
pub const unsafe fn from_start_address_unchecked(
start_address: VirtAddr,
) -> Page<S>
pub const unsafe fn from_start_address_unchecked( start_address: VirtAddr, ) -> Page<S>
Returns the page that starts at the given virtual address.
Safety
The address must be correctly aligned.
pub const fn containing_address(address: VirtAddr) -> Page<S>
pub const fn containing_address(address: VirtAddr) -> Page<S>
Returns the page that contains the given virtual address.
pub const fn start_address(self) -> VirtAddr
pub const fn start_address(self) -> VirtAddr
Returns the start address of the page.
pub const fn p4_index(self) -> PageTableIndex
pub const fn p4_index(self) -> PageTableIndex
Returns the level 4 page table index of this page.
pub const fn p3_index(self) -> PageTableIndex
pub const fn p3_index(self) -> PageTableIndex
Returns the level 3 page table index of this page.
pub const fn page_table_index(self, level: PageTableLevel) -> PageTableIndex
pub const fn page_table_index(self, level: PageTableLevel) -> PageTableIndex
Returns the table index of this page at the specified level.
pub const fn range(start: Page<S>, end: Page<S>) -> PageRange<S> ⓘ
pub const fn range(start: Page<S>, end: Page<S>) -> PageRange<S> ⓘ
Returns a range of pages, exclusive end.
pub const fn range_inclusive(
start: Page<S>,
end: Page<S>,
) -> PageRangeInclusive<S> ⓘ
pub const fn range_inclusive( start: Page<S>, end: Page<S>, ) -> PageRangeInclusive<S> ⓘ
Returns a range of pages, inclusive end.
impl<S> Page<S>where
S: NotGiantPageSize,
impl<S> Page<S>where
S: NotGiantPageSize,
pub const fn p2_index(self) -> PageTableIndex
pub const fn p2_index(self) -> PageTableIndex
Returns the level 2 page table index of this page.
impl Page<Size1GiB>
impl Page<Size1GiB>
pub const fn from_page_table_indices_1gib(
p4_index: PageTableIndex,
p3_index: PageTableIndex,
) -> Page<Size1GiB>
pub const fn from_page_table_indices_1gib( p4_index: PageTableIndex, p3_index: PageTableIndex, ) -> Page<Size1GiB>
Returns the 1GiB memory page with the specified page table indices.
impl Page<Size2MiB>
impl Page<Size2MiB>
pub const fn from_page_table_indices_2mib(
p4_index: PageTableIndex,
p3_index: PageTableIndex,
p2_index: PageTableIndex,
) -> Page<Size2MiB>
pub const fn from_page_table_indices_2mib( p4_index: PageTableIndex, p3_index: PageTableIndex, p2_index: PageTableIndex, ) -> Page<Size2MiB>
Returns the 2MiB memory page with the specified page table indices.
impl Page
impl Page
pub const fn from_page_table_indices(
p4_index: PageTableIndex,
p3_index: PageTableIndex,
p2_index: PageTableIndex,
p1_index: PageTableIndex,
) -> Page
pub const fn from_page_table_indices( p4_index: PageTableIndex, p3_index: PageTableIndex, p2_index: PageTableIndex, p1_index: PageTableIndex, ) -> Page
Returns the 4KiB memory page with the specified page table indices.
pub const fn p1_index(self) -> PageTableIndex
pub const fn p1_index(self) -> PageTableIndex
Returns the level 1 page table index of this page.