Struct PageTableEntry
#[repr(transparent)]pub struct PageTableEntry {
entry: u64,
}Expand description
A 64-bit page table entry.
Fields
entry: u64Implementations
impl PageTableEntry
impl PageTableEntry
pub const fn new() -> PageTableEntry
pub const fn new() -> PageTableEntry
Creates an unused page table entry.
pub fn set_unused(&mut self)
pub fn set_unused(&mut self)
Sets this entry to zero.
pub const fn flags(&self) -> PageTableFlags
pub const fn flags(&self) -> PageTableFlags
Returns the flags of this entry.
pub fn frame(&self) -> Result<PhysFrame, FrameError>
pub fn frame(&self) -> Result<PhysFrame, FrameError>
Returns the physical frame mapped by this entry.
Returns the following errors:
FrameError::FrameNotPresentif the entry doesn’t have thePRESENTflag set.FrameError::HugeFrameif the entry has theHUGE_PAGEflag set (for huge pages theaddrfunction must be used)
pub fn set_addr(&mut self, addr: PhysAddr, flags: PageTableFlags)
pub fn set_addr(&mut self, addr: PhysAddr, flags: PageTableFlags)
Map the entry to the specified physical address with the specified flags.
pub fn set_frame(&mut self, frame: PhysFrame, flags: PageTableFlags)
pub fn set_frame(&mut self, frame: PhysFrame, flags: PageTableFlags)
Map the entry to the specified physical frame with the specified flags.
pub fn set_flags(&mut self, flags: PageTableFlags)
pub fn set_flags(&mut self, flags: PageTableFlags)
Sets the flags of this entry.